% Auto-generated chapter 6 for nasai
% Hadiths in this chapter: 132

\hadithdefcmd{nasai}{494}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخَّرَ الْعَصْرَ شَيْئًا فَقَالَ لَهُ عُرْوَةُ أَمَا إِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ قَدْ نَزَلَ فَصَلَّى أَمَامَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ عُمَرُ اعْلَمْ مَا تَقُولُ يَا عُرْوَةُ ‏.‏ فَقَالَ سَمِعْتُ بَشِيرَ بْنَ أَبِي مَسْعُودٍ يَقُولُ سَمِعْتُ أَبَا مَسْعُودٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَزَلَ جِبْرِيلُ فَأَمَّنِي فَصَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ‏"‏ ‏.‏ يَحْسُبُ بِأَصَابِعِهِ خَمْسَ صَلَوَاتٍ ‏.‏\hadithno{494}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Shihab that 'Umar bin 'Abdul-'Aziz delayed the 'Asr prayer a little. 'Urwah said to him:"Jibril came down and led the Messenger of Allah (ﷺ) in prayer." 'Umar said: "Watch what you are saying, O 'Urwah!" He said: "I heard Bashir bin Abi Mas'ud say: 'I heard Abu Mas'ud say: "I heard the Messenger of Allah (ﷺ) say: 'Jibril came down and led me in prayer, and I prayed with him, then I prayed with him, then I prayed with him, then I prayed with him, then I prayed with him - and he counted off five prayers on his fingers}}
\hadithdefcmd{nasai}{495}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا سَيَّارُ بْنُ سَلاَمَةَ، قَالَ سَمِعْتُ أَبِي يَسْأَلُ أَبَا بَرْزَةَ، عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قُلْتُ أَنْتَ سَمِعْتَهُ قَالَ كَمَا أَسْمَعُكَ السَّاعَةَ فَقَالَ سَمِعْتُ أَبِي يَسْأَلُ عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ لاَ يُبَالِي بَعْضَ تَأْخِيرِهَا - يَعْنِي الْعِشَاءَ - إِلَى نِصْفِ اللَّيْلِ وَلاَ يُحِبُّ النَّوْمَ قَبْلَهَا وَلاَ الْحَدِيثَ بَعْدَهَا ‏.‏ قَالَ شُعْبَةُ ثُمَّ لَقِيتُهُ بَعْدُ فَسَأَلْتُهُ قَالَ كَانَ يُصَلِّي الظُّهْرَ حِينَ تَزُولُ الشَّمْسُ وَالْعَصْرَ يَذْهَبُ الرَّجُلُ إِلَى أَقْصَى الْمَدِينَةِ وَالشَّمْسُ حَيَّةٌ وَالْمَغْرِبَ لاَ أَدْرِي أَىَّ حِينٍ ذَكَرَ ثُمَّ لَقِيتُهُ بَعْدُ فَسَأَلْتُهُ فَقَالَ وَكَانَ يُصَلِّي الصُّبْحَ فَيَنْصَرِفُ الرَّجُلُ فَيَنْظُرُ إِلَى وَجْهِ جَلِيسِهِ الَّذِي يَعْرِفُهُ فَيَعْرِفُهُ ‏.‏ قَالَ وَكَانَ يَقْرَأُ فِيهَا بِالسِّتِّينَ إِلَى الْمِائَةِ ‏.‏\hadithno{495}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Shu'bah said:"Sayyar bin Salamah, narrated to us, he said: 'I heard my father ask Abu Barzah about the prayer of the Messenger of Allah (ﷺ).' I said: 'Did you really hear him?' He said: 'As I can hear you now.' He said: 'I heard my father ask about the prayer of the Messenger of Allah (ﷺ).' He said: 'He would not mind if he delayed it - meaning 'Isha' until midnight, and he did not like to sleep before it or speak after it.'" Shu'bah said: "Then I met him later on and asked him. He said: 'He used to pray Zauhr when the sun had passed its zenith, and (he would pray) 'Asr and a man could walk to the farthest point in Al-Madinah and the sun would still be clear and hot. And Maghrib, I do not know the time he mentioned.' After that I met him and asked him, and he said: 'He used to pray Fajr then after the prayer a man could regarding it, sitting next to him, look at the face of someone he knew and he could recognize it.' He said: 'And he used to recite in it between sixty and one hundred (verses)}}
\hadithdefcmd{nasai}{496}{أَخْبَرَنَا كَثِيرُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ حِينَ زَاغَتِ الشَّمْسُ فَصَلَّى بِهِمْ صَلاَةَ الظُّهْرِ ‏.‏\hadithno{496}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Az-Zuhri he said:"Anas told me that the Messenger of Allah (ﷺ) went out when the sun had passed its zenith, and led them in Zuhr prayer}}
\hadithdefcmd{nasai}{497}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ وَهْبٍ، عَنْ خَبَّابٍ، قَالَ شَكَوْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حَرَّ الرَّمْضَاءِ فَلَمْ يُشْكِنَا ‏.‏ قِيلَ لأَبِي إِسْحَاقَ فِي تَعْجِيلِهَا قَالَ نَعَمْ ‏.‏\hadithno{497}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Khabbab said:"We complained to the Messenger of Alalh (ﷺ) about how hot the sand was, but he did not respond to our complaint." It was said to Abu Ishaq (one of the narrators): "Did they complain regarding his praying it early?" He said: "Yes}}
\hadithdefcmd{nasai}{498}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي حَمْزَةُ الْعَائِذِيُّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا نَزَلَ مَنْزِلاً لَمْ يَرْتَحِلْ مِنْهُ حَتَّى يُصَلِّيَ الظُّهْرَ ‏.‏ فَقَالَ رَجُلٌ وَإِنْ كَانَتْ بِنِصْفِ النَّهَارِ قَالَ وَإِنْ كَانَتْ بِنِصْفِ النَّهَارِ ‏.‏\hadithno{498}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hamzah Al-'A'idhi said:"I heard Anas bin Malik say: 'When the Prophet (ﷺ) halted, he would not move on until he had prayed Zuhr.' A man said: 'Even if it was the middle of the day?' He said: 'Even if it was the middle of the day}}
\hadithdefcmd{nasai}{499}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو سَعِيدٍ، مَوْلَى بَنِي هَاشِمٍ قَالَ حَدَّثَنَا خَالِدُ بْنُ دِينَارٍ أَبُو خَلْدَةَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ الْحَرُّ أَبْرَدَ بِالصَّلاَةِ وَإِذَا كَانَ الْبَرْدُ عَجَّلَ ‏.‏\hadithno{499}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Khalid bin Dinar Abu Khaldah said:"I heard Anas bin Malik say: 'When it was hot, the Messenger of Allah (ﷺ) would wait until it cooled down to pray, and when it was cold he would hasten to pray}}
\hadithdefcmd{nasai}{500}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{500}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'If it is very hot, wait until it cools down before you pray, for intense heat is a breeze from Hell}}
\hadithdefcmd{nasai}{501}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي ح، وَأَنْبَأَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، قَالَ حَدَّثَنَا حَفْصٌ، ح وَأَنْبَأَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، قَالَ حَدَّثَنَا أَبِي، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ، عَنْ يَزِيدَ بْنِ أَوْسٍ، عَنْ ثَابِتِ بْنِ قَيْسٍ، عَنْ أَبِي مُوسَى، يَرْفَعُهُ قَالَ ‏ "‏ أَبْرِدُوا بِالظُّهْرِ فَإِنَّ الَّذِي تَجِدُونَ مِنَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{501}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Musa in a Marfu' [1] report:"Wait until it cools down to pray Zuhr, for the heat you experience is a breeze from Hell." [1] Meaning he attributed it to the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{502}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا جِبْرِيلُ عَلَيْهِ السَّلاَمُ جَاءَكُمْ يُعَلِّمُكُمْ دِينَكُمْ ‏"‏ ‏.‏ فَصَلَّى الصُّبْحَ حِينَ طَلَعَ الْفَجْرُ وَصَلَّى الظُّهْرَ حِينَ زَاغَتِ الشَّمْسُ ثُمَّ صَلَّى الْعَصْرَ حِينَ رَأَى الظِّلَّ مِثْلَهُ ثُمَّ صَلَّى الْمَغْرِبَ حِينَ غَرَبَتِ الشَّمْسُ وَحَلَّ فِطْرُ الصَّائِمِ ثُمَّ صَلَّى الْعِشَاءَ حِينَ ذَهَبَ شَفَقُ اللَّيْلِ ثُمَّ جَاءَهُ الْغَدَ فَصَلَّى بِهِ الصُّبْحَ حِينَ أَسْفَرَ قَلِيلاً ثُمَّ صَلَّى بِهِ الظُّهْرَ حِينَ كَانَ الظِّلُّ مِثْلَهُ ثُمَّ صَلَّى الْعَصْرَ حِينَ كَانَ الظِّلُّ مِثْلَيْهِ ثُمَّ صَلَّى الْمَغْرِبَ بِوَقْتٍ وَاحِدٍ حِينَ غَرَبَتِ الشَّمْسُ وَحَلَّ فِطْرُ الصَّائِمِ ثُمَّ صَلَّى الْعِشَاءَ حِينَ ذَهَبَ سَاعَةٌ مِنَ اللَّيْلِ ثُمَّ قَالَ ‏"‏ الصَّلاَةُ مَا بَيْنَ صَلاَتِكَ أَمْسِ وَصَلاَتِكَ الْيَوْمَ ‏"‏ ‏.‏\hadithno{502}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: This is 'Jibril, peace be upon you, he came to teach you your religion. He prayed Subh when the dawn appeared, and he prayed Zuhr when the sun had (passed its zenith), and he prayed 'Asr when he saw that the shadow of a thing was equal to its height, then he prayed Maghrib when the sub had set and it is permissible for the fasting person to eat. Then he prayed 'Isha' when the twilight had disappeared. Then he came to him the following day and prayed Subh when it had got a little lighter, then he prayed Zuhr when the shadow of a thing was equal to its height, then he prayed 'Asr when the shadow of a thing was equal to twice its height, then he prayed Maghrib at the same time as before, then he prayed 'Isha' when a short period of the night had passed. Then he said: 'The prayer is between the times when you prayed yesterday and the times when you prayed today}}
\hadithdefcmd{nasai}{503}{أَخْبَرَنَا أَبُو عَبْدِ الرَّحْمَنِ عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الأَذْرَمِيُّ، قَالَ حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، سَعْدِ بْنِ طَارِقٍ عَنْ كَثِيرِ بْنِ مُدْرِكٍ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كَانَ قَدْرُ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم الظُّهْرَ فِي الصَّيْفِ ثَلاَثَةَ أَقْدَامٍ إِلَى خَمْسَةِ أَقْدَامٍ وَفِي الشِّتَاءِ خَمْسَةَ أَقْدَامٍ إِلَى سَبْعَةِ أَقْدَامٍ ‏.‏\hadithno{503}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"The Prophet (ﷺ) prayed Zuhr when the length of (a person's shadow) was between three and five feet in summer, and between five and seven feet in winter}}
\hadithdefcmd{nasai}{504}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا ثَوْرٌ، حَدَّثَنِي سُلَيْمَانُ بْنُ مُوسَى، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرٍ، قَالَ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ مَوَاقِيتِ الصَّلاَةِ فَقَالَ ‏ "‏ صَلِّ مَعِي ‏"‏ ‏.‏ فَصَلَّى الظُّهْرَ حِينَ زَاغَتِ الشَّمْسُ وَالْعَصْرَ حِينَ كَانَ فَىْءُ كُلِّ شَىْءٍ مِثْلَهُ وَالْمَغْرِبَ حِينَ غَابَتِ الشَّمْسُ وَالْعِشَاءَ حِينَ غَابَ الشَّفَقُ قَالَ ثُمَّ صَلَّى الظُّهْرَ حِينَ كَانَ فَىْءُ الإِنْسَانِ مِثْلَهُ وَالْعَصْرَ حِينَ كَانَ فَىْءُ الإِنْسَانِ مِثْلَيْهِ وَالْمَغْرِبَ حِينَ كَانَ قُبَيْلَ غَيْبُوبَةِ الشَّفَقِ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ الْحَارِثِ ثُمَّ قَالَ فِي الْعِشَاءِ أُرَى إِلَى ثُلُثِ اللَّيْلِ ‏.‏\hadithno{504}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir said:"A man asked the Messenger of Allah (ﷺ) about the times of prayer. He said: 'Pray with me.' So he prayed Zuhr when the sun had passsed its zenith, 'Asr when the shadow of a thing was equal to its height, Maghrib when the sun had set and 'Isha' when the twilight had disappeared." He said: "Then he prayed Zuhr when the shadow of a man was equal in length to his height, 'Asr when the length of a man's shadow was twice his height, and Maghrib just before the twilight disappeared." (One of the narrators) 'Abdullah bin Al-Harith said: "then he said: 'With regard to 'Isha' I think it is up to one-third of the night.'" [1] [1] The speaker there is Thawr, who narrated it from 'Ata' from Jabir}}
\hadithdefcmd{nasai}{505}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى صَلاَةَ الْعَصْرِ وَالشَّمْسُ فِي حُجْرَتِهَا لَمْ يَظْهَرِ الْفَىْءُ مِنْ حُجْرَتِهَا ‏.‏\hadithno{505}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) prayed 'Asr when the sun was in her room and the shadow had not appeared on her wall}}
\hadithdefcmd{nasai}{506}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، وَإِسْحَاقُ بْنُ عَبْدِ اللَّهِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ ثُمَّ يَذْهَبُ الذَّاهِبُ إِلَى قُبَاءٍ فَقَالَ أَحَدُهُمَا فَيَأْتِيهِمْ وَهُمْ يُصَلُّونَ وَقَالَ الآخَرُ وَالشَّمْسُ مُرْتَفِعَةٌ ‏.‏\hadithno{506}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas:"The Messenger of Allah (ﷺ) used to pray 'Asr, then a person could go to Quba'." One of them [1] said: "And he would come to them when they were prayed." The other said: "And the sub was still high." [1] Both Az-Zuhri and Ishaq bin 'Abdullah narrated it from Anas, so the reference is about them}}
\hadithdefcmd{nasai}{507}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ حَيَّةٌ وَيَذْهَبُ الذَّاهِبُ إِلَى الْعَوَالِي وَالشَّمْسُ مُرْتَفِعَةٌ ‏.‏\hadithno{507}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) used to pray 'Asr when the sun was still high and bright, and a person could go to Al-'Awali [1] when the sun was still high." [1] Al-'Awali is the southern most district of Al-Madinah, and it is very big. Its nearest limit is at a distance of about two miles from the center of Al-Madinah. While its furthest limit is about eight miles}}
\hadithdefcmd{nasai}{508}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ أَبِي الأَبْيَضِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِنَا الْعَصْرَ وَالشَّمْسُ بَيْضَاءُ مُحَلِّقَةٌ ‏.‏\hadithno{508}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) used to lead us in 'Asr prayer when the sun was still bright and high}}
\hadithdefcmd{nasai}{509}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ أَبِي بَكْرِ بْنِ عُثْمَانَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ بْنَ سَهْلٍ، يَقُولُ صَلَّيْنَا مَعَ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ الظُّهْرَ ثُمَّ خَرَجْنَا حَتَّى دَخَلْنَا عَلَى أَنَسِ بْنِ مَالِكٍ فَوَجَدْنَاهُ يُصَلِّي الْعَصْرَ قُلْتُ يَا عَمِّ مَا هَذِهِ الصَّلاَةُ الَّتِي صَلَّيْتَ قَالَ الْعَصْرَ وَهَذِهِ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي كُنَّا نُصَلِّي ‏.‏\hadithno{509}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Bakr bin 'Uthman bin Sahl bin Hunaif said:"I heard Abu Umamah bin Sahl say: 'We prayed Zuhr with 'Umar bin 'Abdul-'Aziz, then we went out and entered upon Anas bin Malik, and we found him praying 'Asr.'" I said: "O uncle, what is this prayer that you prayed?" He said: "'Asr; this is the prayer of the Messenger of Allah (ﷺ) that we used to pray with him}}
\hadithdefcmd{nasai}{510}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو عَلْقَمَةَ الْمَدَنِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، قَالَ صَلَّيْنَا فِي زَمَانِ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ ثُمَّ انْصَرَفْنَا إِلَى أَنَسِ بْنِ مَالِكٍ فَوَجَدْنَاهُ يُصَلِّي فَلَمَّا انْصَرَفَ قَالَ لَنَا أَصَلَّيْتُمْ قُلْنَا صَلَّيْنَا الظُّهْرَ ‏.‏ قَالَ إِنِّي صَلَّيْتُ الْعَصْرَ ‏.‏ فَقَالُوا لَهُ عَجَّلْتَ ‏.‏ فَقَالَ إِنَّمَا أُصَلِّي كَمَا رَأَيْتُ أَصْحَابِي يُصَلُّونَ ‏.‏\hadithno{510}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Salamah said:"We prayed at the time of 'Umar bin 'Abdul-'Aziz, then we went to Anas bin Malik and found him praying. when he finished he said to us: 'Have you prayed?' We said: 'We prayed Zuhr.' He said: 'I prayed 'Asr.' They said: 'You have prayed early.' He said: 'Rather I prayed as I saw my companions pray}}
\hadithdefcmd{nasai}{511}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرِ بْنِ إِيَاسِ بْنِ مُقَاتِلِ بْنِ مُشَمْرِجِ بْنِ خَالِدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا الْعَلاَءُ، أَنَّهُ دَخَلَ عَلَى أَنَسِ بْنِ مَالِكٍ فِي دَارِهِ بِالْبَصْرَةِ حِينَ انْصَرَفَ مِنَ الظُّهْرِ - وَدَارُهُ بِجَنْبِ الْمَسْجِدِ - فَلَمَّا دَخَلْنَا عَلَيْهِ قَالَ أَصَلَّيْتُمُ الْعَصْرَ قُلْنَا لاَ إِنَّمَا انْصَرَفْنَا السَّاعَةَ مِنَ الظُّهْرِ ‏.‏ قَالَ فَصَلُّوا الْعَصْرَ ‏.‏ قَالَ فَقُمْنَا فَصَلَّيْنَا فَلَمَّا انْصَرَفْنَا قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تِلْكَ صَلاَةُ الْمُنَافِقِ جَلَسَ يَرْقُبُ صَلاَةَ الْعَصْرِ حَتَّى إِذَا كَانَتْ بَيْنَ قَرْنَىِ الشَّيْطَانِ قَامَ فَنَقَرَ أَرْبَعًا لاَ يَذْكُرُ اللَّهَ عَزَّ وَجَلَّ فِيهَا إِلاَّ قَلِيلاً ‏"‏ ‏.‏\hadithno{511}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Al-'Ala' narrated to us that he entered upon Anas bin Malik in his house in Al-Basrah, when he had finished Zuhr, and his house was beside the Masjid. "When we entered upon him, he said:'Have you prayed 'Asr?' We said: 'No, we have just finished Zuhr.' He said: 'Pray 'Asr.' So we got up and prayed, and when we finished he said: 'I heard the Messenger of Allah (ﷺ) say: "That is the prayer of the hypocrite: he sits and delays 'Asr prayer until (the sun) is between the horns of the Shaitan, then he gets up and pecks four (Rak'ahs) in which he only remembers Allah a little}}
\hadithdefcmd{nasai}{512}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الَّذِي تَفُوتُهُ صَلاَةُ الْعَصْرِ فَكَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏ ‏.‏ أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الَّذِي تَفُوتُهُ صَلاَةُ الْعَصْرِ فَكَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏ ‏.‏\hadithno{512}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim, from his father, that the Messenger of Allah (ﷺ) said:"The one who misses 'Asr prayer, it is as if he has been robbed of his family and his wealth." It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said: "The one who misses 'Asr prayer, it is as if he has been robbed of his family and his wealth}}
\hadithdefcmd{nasai}{513}{أَخْبَرَنَا يُوسُفُ بْنُ وَاضِحٍ، قَالَ حَدَّثَنَا قُدَامَةُ، - يَعْنِي ابْنَ شِهَابٍ - عَنْ بُرْدٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ جِبْرِيلَ، أَتَى النَّبِيَّ صلى الله عليه وسلم يُعَلِّمُهُ مَوَاقِيتَ الصَّلاَةِ فَتَقَدَّمَ جِبْرِيلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ وَالنَّاسُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى الظُّهْرَ حِينَ زَالَتِ الشَّمْسُ وَأَتَاهُ حِينَ كَانَ الظِّلُّ مِثْلَ شَخْصِهِ فَصَنَعَ كَمَا صَنَعَ فَتَقَدَّمَ جِبْرِيلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ وَالنَّاسُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى الْعَصْرَ ثُمَّ أَتَاهُ حِينَ وَجَبَتِ الشَّمْسُ فَتَقَدَّمَ جِبْرِيلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ وَالنَّاسُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى الْمَغْرِبَ ثُمَّ أَتَاهُ حِينَ غَابَ الشَّفَقُ فَتَقَدَّمَ جِبْرِيلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ وَالنَّاسُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى الْعِشَاءَ ثُمَّ أَتَاهُ حِينَ انْشَقَّ الْفَجْرُ فَتَقَدَّمَ جِبْرِيلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ وَالنَّاسُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى الْغَدَاةَ ثُمَّ أَتَاهُ الْيَوْمَ الثَّانِيَ حِينَ كَانَ ظِلُّ الرَّجُلِ مِثْلَ شَخْصِهِ فَصَنَعَ مِثْلَ مَا صَنَعَ بِالأَمْسِ فَصَلَّى الظُّهْرَ ثُمَّ أَتَاهُ حِينَ كَانَ ظِلُّ الرَّجُلِ مِثْلَ شَخْصَيْهِ فَصَنَعَ كَمَا صَنَعَ بِالأَمْسِ فَصَلَّى الْعَصْرَ ثُمَّ أَتَاهُ حِينَ وَجَبَتِ الشَّمْسُ فَصَنَعَ كَمَا صَنَعَ بِالأَمْسِ فَصَلَّى الْمَغْرِبَ فَنِمْنَا ثُمَّ قُمْنَا ثُمَّ نِمْنَا ثُمَّ قُمْنَا فَأَتَاهُ فَصَنَعَ كَمَا صَنَعَ بِالأَمْسِ فَصَلَّى الْعِشَاءَ ثُمَّ أَتَاهُ حِينَ امْتَدَّ الْفَجْرُ وَأَصْبَحَ وَالنُّجُومُ بَادِيَةٌ مُشْتَبِكَةٌ فَصَنَعَ كَمَا صَنَعَ بِالأَمْسِ فَصَلَّى الْغَدَاةَ ثُمَّ قَالَ ‏ "‏ مَا بَيْنَ هَاتَيْنِ الصَّلاَتَيْنِ وَقْتٌ ‏"‏ ‏.‏\hadithno{513}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir bin 'Abdullah that Jibril came to the Prophet (ﷺ) to teach him the times of prayer. Jibril went forward, with the Messenger of Allah (ﷺ) behind him and the people behind the Messenger of Allah (ﷺ), and he prayed Zurh when the sun had passed its zenith. Then he came to him when the shadow of a person was equal to his height, and did as he had done before; Jibril went forward, with the Messenger of Allah (ﷺ) behind him and the people behind the Messenger of Allah (ﷺ), and he prayed 'Asr. Then Jibril came to him when the sun had set; Jibril went forward, with the Messenger of Allah (ﷺ) behind him and the people behind the Messenger of Allah (ﷺ), and he prayed Al-Ghadah. [1] Then he came to him on the second day when a man's shadow was equal to his height, and did as he had done the day before, he prayed Zuhr. Then he came to him when the shadow of a man was twice his height, and did what he had done the day before, and prayed 'Asr. Then he came to him when the sun had set and did what he had done the day before, and prayed Maghrib. Then we slept and got up, and slept and got up again. Then he came to him and did what he had done the day before and prayed 'Isha.' The he came to him when the (the light of) dawn was spread (on the horizon) [2] and the starts were still clear in the sky, and he did the same as he had done the day before, and prayed Al-Ghadah. Then he said:' The time between these two is the time for prayer.'" [1] Meaning Fajr, the morning prayer. [2] The Fajr prayer was elongated because the Prophet recited at length during the prayer, so that it ended just before sunrise. That defined the end of the time for Fajr, as the beginning of the time was defined by the moment when he started the first Rak'ah}}
\hadithdefcmd{nasai}{514}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ مَعْمَرًا، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَتَيْنِ مِنْ صَلاَةِ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ أَوْ رَكْعَةً مِنْ صَلاَةِ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ ‏"‏ ‏.‏\hadithno{514}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah, may Allah be pleased with him, that the Prophet (ﷺ) said:"Whoever catches up with two Rak'ahs of 'Asr prayer before the sun sets, or one Rak'ah of the Subh prayer before the sun rises, has caught it}}
\hadithdefcmd{nasai}{515}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ مَعْمَرًا، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنْ صَلاَةِ الْعَصْرِ قَبْلَ أَنْ تَغِيبَ الشَّمْسُ أَوْ أَدْرَكَ رَكْعَةً مِنَ الْفَجْرِ قَبْلَ طُلُوعِ الشَّمْسِ فَقَدْ أَدْرَكَ ‏"‏ ‏.‏\hadithno{515}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Whoever catches up with one Rak'ah of 'Asr prayer before the sun sets, or catches up with one Rak'ah of Fajr before the sun rises, has caught it}}
\hadithdefcmd{nasai}{516}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَدْرَكَ أَحَدُكُمْ أَوَّلَ سَجْدَةٍ مِنْ صَلاَةِ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَلْيُتِمَّ صَلاَتَهُ وَإِذَا أَدْرَكَ أَوَّلَ سَجْدَةٍ مِنْ صَلاَةِ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَلْيُتِمَّ صَلاَتَهُ ‏"‏ ‏.‏\hadithno{516}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"If any one of you catches the first prostration of 'Asr prayer before the sun sets, let him complete his prayer, and if he catches up with the first prostration of Fajr prayer before the sub rises, let him complete his prayer}}
\hadithdefcmd{nasai}{517}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، وَعَنْ بُسْرِ بْنِ سَعِيدٍ، وَعَنِ الأَعْرَجِ، يُحَدِّثُونَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنْ صَلاَةِ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ الصُّبْحَ وَمَنْ أَدْرَكَ رَكْعَةً مِنَ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَ الْعَصْرَ ‏"‏ ‏.‏\hadithno{517}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Whoever catches up with a Rak'ah of the Subh prayer before the sun rises, then he has caught up with Subh, and whoever catches up with a Rak'ah of 'Asr prayer before the sun sets, then he has caught up with 'Asr}}
\hadithdefcmd{nasai}{518}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ نَصْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَدِّهِ، مُعَاذٍ أَنَّهُ طَافَ مَعَ مُعَاذِ ابْنِ عَفْرَاءَ فَلَمْ يُصَلِّ فَقُلْتُ أَلاَ تُصَلِّي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ بَعْدَ الْعَصْرِ حَتَّى تَغِيبَ الشَّمْسُ وَلاَ بَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{518}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Nasr bin 'Abdur-Rahman, from his grandfather Mu'adh, that he performed Tawaf with Mu'adh bin 'Afra' but he did not pray. "I said:'Are you not going to pray?' He said: 'The Messenger of Allah (ﷺ) said: 'There is no prayer after 'Asr until the sun has set, nor after Subh until the sun has risen}}
\hadithdefcmd{nasai}{519}{أَخْبَرَنِي عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنْ وَقْتِ الصَّلاَةِ فَقَالَ ‏"‏ أَقِمْ مَعَنَا هَذَيْنِ الْيَوْمَيْنِ ‏"‏ ‏.‏ فَأَمَرَ بِلاَلاً فَأَقَامَ عِنْدَ الْفَجْرِ فَصَلَّى الْفَجْرَ ثُمَّ أَمَرَهُ حِينَ زَالَتِ الشَّمْسُ فَصَلَّى الظُّهْرَ ثُمَّ أَمَرَهُ حِينَ رَأَى الشَّمْسَ بَيْضَاءَ فَأَقَامَ الْعَصْرَ ثُمَّ أَمَرَهُ حِينَ وَقَعَ حَاجِبُ الشَّمْسِ فَأَقَامَ الْمَغْرِبَ ثُمَّ أَمَرَهُ حِينَ غَابَ الشَّفَقُ فَأَقَامَ الْعِشَاءَ ثُمَّ أَمَرَهُ مِنَ الْغَدِ فَنَوَّرَ بِالْفَجْرِ ثُمَّ أَبْرَدَ بِالظُّهْرِ وَأَنْعَمَ أَنْ يُبْرِدَ ثُمَّ صَلَّى الْعَصْرَ وَالشَّمْسُ بَيْضَاءُ وَأَخَّرَ عَنْ ذَلِكَ ثُمَّ صَلَّى الْمَغْرِبَ قَبْلَ أَنْ يَغِيبَ الشَّفَقُ ثُمَّ أَمَرَهُ فَأَقَامَ الْعِشَاءَ حِينَ ذَهَبَ ثُلُثُ اللَّيْلِ فَصَلاَّهَا ثُمَّ قَالَ ‏"‏ أَيْنَ السَّائِلُ عَنْ وَقْتِ الصَّلاَةِ وَقْتُ صَلاَتِكُمْ مَا بَيْنَ مَا رَأَيْتُمْ ‏"‏ ‏.‏\hadithno{519}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Buraidah that his father said:"A man came to the Messenger of Allah (ﷺ) and asked him about the times of prayer. He said: 'Stay with us for these two days.' Then he told Bilal to say the Iqamah at dawn and he prayed Fajr. Then he told him to do that when the sun had passed its zenith and he prayed Zuhr. Then he told him to do that when the sun was still bright, and he said the Iqamah for 'Asr. Then he told him to do that when the last part of the sun had dissapeared, and he said the Iqamah for Maghrib. Then he told him to do that when the twilight had disappeared and he said the Iqamah for 'Isha'. The following day, he prayed Fajr when there was light, then he delayed Zuhr until it was cooler, and waited until it was much cooler before praying 'Asr but the sun was still clear, so he prayed 'Asr later than on the first day. Then he prayed Maghrib before the twilight disappeared. Then he told him to say the Iqamah for 'Isha' when one-third of the night had passed, and he prayed, then he said: 'Where is the one who was asking about the times of prayer? The times of your prayer are between the times you have seen}}
\hadithdefcmd{nasai}{520}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، قَالَ سَمِعْتُ حَسَّانَ بْنَ بِلاَلٍ، عَنْ رَجُلٍ، مِنْ أَسْلَمَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمْ كَانُوا يُصَلُّونَ مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم الْمَغْرِبَ ثُمَّ يَرْجِعُونَ إِلَى أَهَالِيهِمْ إِلَى أَقْصَى الْمَدِينَةِ يَرْمُونَ وَيُبْصِرُونَ مَوَاقِعَ سِهَامِهِمْ ‏.‏\hadithno{520}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from a man of Aslam, who was one of the Companions of the Prophet (ﷺ), that they used to pray Maghrib with the Prophet (ﷺ),then they would go back to their families in the furthest part of Al-Madinah, shooting arrows and seeing where they landed. [1] [1] Because it was still bright enough}}
\hadithdefcmd{nasai}{521}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ خَيْرِ بْنِ نُعَيْمٍ الْحَضْرَمِيِّ، عَنِ ابْنِ هُبَيْرَةَ، عَنْ أَبِي تَمِيمٍ الْجَيْشَانِيِّ، عَنْ أَبِي بَصْرَةَ الْغِفَارِيِّ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ بِالْمُخَمَّصِ قَالَ ‏ "‏ إِنَّ هَذِهِ الصَّلاَةَ عُرِضَتْ عَلَى مَنْ كَانَ قَبْلَكُمْ فَضَيَّعُوهَا وَمَنْ حَافَظَ عَلَيْهَا كَانَ لَهُ أَجْرُهُ مَرَّتَيْنِ وَلاَ صَلاَةَ بَعْدَهَا حَتَّى يَطْلُعَ الشَّاهِدُ ‏"‏ ‏.‏ وَالشَّاهِدُ النَّجْمُ ‏.‏\hadithno{521}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Basrah Al-Ghifari said:"The Messenger of Allah (ﷺ) led us in praying 'Asr in Al-Mukhammas. He said: 'This prayer was enjoined upon those who came before you, but they neglected it. Whoever prays it regularly will have a two-fold reward, and there is no prayer after it until the Shahid appears." And the Shahid is "the star." [1] [1] This is a statement of one of the narrators, and Allah knows best}}
\hadithdefcmd{nasai}{522}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا أَيُّوبَ الأَزْدِيَّ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، - قَالَ شُعْبَةُ كَانَ قَتَادَةُ يَرْفَعُهُ أَحْيَانًا وَأَحْيَانًا لاَ يَرْفَعُهُ - قَالَ ‏ "‏ وَقْتُ صَلاَةِ الظُّهْرِ مَا لَمْ تَحْضُرِ الْعَصْرُ وَوَقْتُ صَلاَةِ الْعَصْرِ مَا لَمْ تَصْفَرَّ الشَّمْسُ وَوَقْتُ الْمَغْرِبِ مَا لَمْ يَسْقُطْ ثَوْرُ الشَّفَقِ وَوَقْتُ الْعِشَاءِ مَا لَمْ يَنْتَصِفِ اللَّيْلُ وَوَقْتُ الصُّبْحِ مَا لَمْ تَطْلُعِ الشَّمْسُ ‏"‏ ‏.‏\hadithno{522}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Amr - and (one of the narrators) Shu'bah said:"Sometimes he (Qatadah, his teacher) narrated it as a Marfu' report and sometimes he did not" - "The time for Zuhr prayer is until 'Asr comes, and the time for 'Asr prayer is until the sun turns yellow. the time for Maghrib is until the twilight disappears, and the time for 'Isha' is until the night is halfway through, and the time for Subh is until the sun rises}}
\hadithdefcmd{nasai}{523}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، وَأَحْمَدُ بْنُ سُلَيْمَانَ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ بَدْرِ بْنِ عُثْمَانَ، قَالَ إِمْلاَءً عَلَىَّ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي مُوسَى، عَنْ أَبِيهِ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم سَائِلٌ يَسْأَلُهُ عَنْ مَوَاقِيتِ الصَّلاَةِ فَلَمْ يَرُدَّ عَلَيْهِ شَيْئًا فَأَمَرَ بِلاَلاً فَأَقَامَ بِالْفَجْرِ حِينَ انْشَقَّ ثُمَّ أَمَرَهُ فَأَقَامَ بِالظُّهْرِ حِينَ زَالَتِ الشَّمْسُ وَالْقَائِلُ يَقُولُ انْتَصَفَ النَّهَارُ وَهُوَ أَعْلَمُ ثُمَّ أَمَرَهُ فَأَقَامَ بِالْعَصْرِ وَالشَّمْسُ مُرْتَفِعَةٌ ثُمَّ أَمَرَهُ فَأَقَامَ بِالْمَغْرِبِ حِينَ غَرَبَتِ الشَّمْسُ ثُمَّ أَمَرَهُ فَأَقَامَ بِالْعِشَاءِ حِينَ غَابَ الشَّفَقُ ثُمَّ أَخَّرَ الْفَجْرَ مِنَ الْغَدِ حِينَ انْصَرَفَ وَالْقَائِلُ يَقُولُ طَلَعَتِ الشَّمْسُ ثُمَّ أَخَّرَ الظُّهْرَ إِلَى قَرِيبٍ مِنْ وَقْتِ الْعَصْرِ بِالأَمْسِ ثُمَّ أَخَّرَ الْعَصْرَ حَتَّى انْصَرَفَ وَالْقَائِلُ يَقُولُ احْمَرَّتِ الشَّمْسُ ثُمَّ أَخَّرَ الْمَغْرِبَ حَتَّى كَانَ عِنْدَ سُقُوطِ الشَّفَقِ ثُمَّ أَخَّرَ الْعِشَاءَ إِلَى ثُلُثِ اللَّيْلِ ثُمَّ قَالَ ‏ "‏ الْوَقْتُ فِيمَا بَيْنَ هَذَيْنِ ‏"‏ ‏.‏\hadithno{523}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Bakr bin Abi Musa narrated that his father said:"A man came to the Prophet (ﷺ) asking him about the times of prayer, and he did not answer him. He told Bilal to say the Iqamah at dawn broke, then he told him to say the Iqamah for Zuhr when the sun had passed its zenith and a person would say: 'It is the middle of the day,' but he (the Prophet (ﷺ)) knew better. Then he told him to say the Iqamah for 'Asr when the sun was still high. Then he told him to say the Iqamah for Maghrib when the sun had set. Then he told him to say the Iqamah for 'Isha' when the twilight had dissapeared. Then the next day he told him to say the Iqamah for Fajr, at a time such that when after he had finished one would say: 'The sun has risen.' Then he delayed Zuhr until it was nearly the time of 'Asr compared to the day before. Then he delayed 'Asr, to a time such that when he finished one would say: 'The su has turned red.' Then he delayed Maghrib until the twilight was about to disappear. Then he delayed 'Isha' until one-third of the night had passed. Then he said: 'The time (for prayer) is between these times}}
\hadithdefcmd{nasai}{524}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، قَالَ حَدَّثَنَا خَارِجَةُ بْنُ عَبْدِ اللَّهِ بْنِ سُلَيْمَانَ بْنِ زَيْدِ بْنِ ثَابِتٍ، قَالَ حَدَّثَنِي الْحُسَيْنُ بْنُ بَشِيرِ بْنِ سَلاَّمٍ، عَنْ أَبِيهِ، قَالَ دَخَلْتُ أَنَا وَمُحَمَّدُ بْنُ عَلِيٍّ، عَلَى جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ فَقُلْنَا لَهُ أَخْبِرْنَا عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَاكَ زَمَنُ الْحَجَّاجِ بْنِ يُوسُفَ ‏.‏ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى الظُّهْرَ حِينَ زَالَتِ الشَّمْسُ وَكَانَ الْفَىْءُ قَدْرَ الشِّرَاكِ ثُمَّ صَلَّى الْعَصْرَ حِينَ كَانَ الْفَىْءُ قَدْرَ الشِّرَاكِ وَظِلِّ الرَّجُلِ ثُمَّ صَلَّى الْمَغْرِبَ حِينَ غَابَتِ الشَّمْسُ ثُمَّ صَلَّى الْعِشَاءَ حِينَ غَابَ الشَّفَقُ ثُمَّ صَلَّى الْفَجْرَ حِينَ طَلَعَ الْفَجْرُ ثُمَّ صَلَّى مِنَ الْغَدِ الظُّهْرَ حِينَ كَانَ الظِّلُّ طُولَ الرَّجُلِ ثُمَّ صَلَّى الْعَصْرَ حِينَ كَانَ ظِلُّ الرَّجُلِ مِثْلَيْهِ قَدْرَ مَا يَسِيرُ الرَّاكِبُ سَيْرَ الْعَنَقِ إِلَى ذِي الْحُلَيْفَةِ ثُمَّ صَلَّى الْمَغْرِبَ حِينَ غَابَتِ الشَّمْسُ ثُمَّ صَلَّى الْعِشَاءَ إِلَى ثُلُثِ اللَّيْلِ أَوْ نِصْفِ اللَّيْلِ - شَكَّ زَيْدٌ - ثُمَّ صَلَّى الْفَجْرَ فَأَسْفَرَ ‏.‏\hadithno{524}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Al-Husain bin Bashir bin Sallam narrated that his father said:"Muhammad bin 'Ali and I entered upon Jabir bin 'Abdullah Al-Ansari. We said to him: 'Tell us about the prayer of the Messenger of Allah (ﷺ).' That was at the time of Al-Hajjaj bin Yusuf. He said: 'The Messenger of Allah (ﷺ) came out and prayed Zuhr when the sun had passed its zenith and the shadow (of a thing) was the length of a sandal-strap. Then he prayed 'Asr when the shadow of a man was the length of a sandal-strap plus his height. Then he prayed Maghrib when the sun had set. Then he prayed 'Isha' when the twilight disappeared. Then he prayed Fajr when dawn broke. The next day he prayed Zuhr when a man's shadow was equal to his height. Then he prayed 'Asr when a man's shadow was twice his height, and (the time between the prayer and sunset) lasted as long as it takes a swift rider to reach Dhul-Hulaifah. Then he prayed Maghrib when the sun set, then he prayed 'Isha' when one-third or one-half of the night had passed'" - (One of the narrators) Zaid, was not sure - "then he prayed Fajr when it had become bright}}
\hadithdefcmd{nasai}{525}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عَوْفٌ، قَالَ حَدَّثَنِي سَيَّارُ بْنُ سَلاَمَةَ، قَالَ دَخَلْتُ عَلَى أَبِي بَرْزَةَ فَسَأَلَهُ أَبِي كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْمَكْتُوبَةَ قَالَ كَانَ يُصَلِّي الْهَجِيرَ الَّتِي تَدْعُونَهَا الأُولَى حِينَ تَدْحَضُ الشَّمْسُ وَكَانَ يُصَلِّي الْعَصْرَ حِينَ يَرْجِعُ أَحَدُنَا إِلَى رَحْلِهِ فِي أَقْصَى الْمَدِينَةِ وَالشَّمْسُ حَيَّةٌ وَنَسِيتُ مَا قَالَ فِي الْمَغْرِبِ وَكَانَ يَسْتَحِبُّ أَنْ يُؤَخِّرَ الْعِشَاءَ الَّتِي تَدْعُونَهَا الْعَتَمَةَ وَكَانَ يَكْرَهُ النَّوْمَ قَبْلَهَا وَالْحَدِيثَ بَعْدَهَا وَكَانَ يَنْفَتِلُ مِنْ صَلاَةِ الْغَدَاةِ حِينَ يَعْرِفُ الرَّجُلُ جَلِيسَهُ وَكَانَ يَقْرَأُ بِالسِّتِّينَ إِلَى الْمِائَةِ ‏.‏\hadithno{525}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sayyar bin Salamah said:"I entered upon Abu Barzah, and my fatehr asked him: 'How did the Messenger of Allah (ﷺ) pray the prescribed prayers?' He said: 'He used to pray Zuhr, which you call Al-Uula (the first) when the sun passed its zenith; he used to pray 'Asr when one of us could go back to his hoome in the farthest part of Al-Madinah while the sun was still bright.' I forgot what he said about Maghrib. 'And he used to like to delay 'Isha', which you call Al-'Atamah, and he did not like to sleep before it nor talk after it. And he used to finish the Al-Ghadah (Fajr) prayer when a man could recognize his neighbor, and he used to recite (in it) between sixty and one hundred verses}}
\hadithdefcmd{nasai}{526}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حُسَيْنِ بْنِ عَلِيِّ بْنِ حُسَيْنٍ، قَالَ أَخْبَرَنِي وَهْبُ بْنُ كَيْسَانَ، قَالَ حَدَّثَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ، قَالَ جَاءَ جِبْرِيلُ عَلَيْهِ السَّلاَمُ إِلَى النَّبِيِّ صلى الله عليه وسلم حِينَ زَالَتِ الشَّمْسُ فَقَالَ قُمْ يَا مُحَمَّدُ فَصَلِّ الظُّهْرَ حِينَ مَالَتِ الشَّمْسُ ثُمَّ مَكَثَ حَتَّى إِذَا كَانَ فَىْءُ الرَّجُلِ مِثْلَهُ جَاءَهُ لِلْعَصْرِ فَقَالَ قُمْ يَا مُحَمَّدُ فَصَلِّ الْعَصْرَ ‏.‏ ثُمَّ مَكَثَ حَتَّى إِذَا غَابَتِ الشَّمْسُ جَاءَهُ فَقَالَ قُمْ فَصَلِّ الْمَغْرِبَ فَقَامَ فَصَلاَّهَا حِينَ غَابَتِ الشَّمْسُ سَوَاءً ثُمَّ مَكَثَ حَتَّى إِذَا ذَهَبَ الشَّفَقُ جَاءَهُ فَقَالَ قُمْ فَصَلِّ الْعِشَاءَ ‏.‏ فَقَامَ فَصَلاَّهَا ثُمَّ جَاءَهُ حِينَ سَطَعَ الْفَجْرُ فِي الصُّبْحِ فَقَالَ قُمْ يَا مُحَمَّدُ فَصَلِّ ‏.‏ فَقَامَ فَصَلَّى الصُّبْحَ ثُمَّ جَاءَهُ مِنَ الْغَدِ حِينَ كَانَ فَىْءُ الرَّجُلِ مِثْلَهُ فَقَالَ قُمْ يَا مُحَمَّدُ فَصَلِّ ‏.‏ فَصَلَّى الظُّهْرَ ثُمَّ جَاءَهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ حِينَ كَانَ فَىْءُ الرَّجُلِ مِثْلَيْهِ فَقَالَ قُمْ يَا مُحَمَّدُ فَصَلِّ ‏.‏ فَصَلَّى الْعَصْرَ ثُمَّ جَاءَهُ لِلْمَغْرِبِ حِينَ غَابَتِ الشَّمْسُ وَقْتًا وَاحِدًا لَمْ يَزُلْ عَنْهُ فَقَالَ قُمْ فَصَلِّ ‏.‏ فَصَلَّى الْمَغْرِبَ ثُمَّ جَاءَهُ لِلْعِشَاءِ حِينَ ذَهَبَ ثُلُثُ اللَّيْلِ الأَوَّلُ فَقَالَ قُمْ فَصَلِّ ‏.‏ فَصَلَّى الْعِشَاءَ ثُمَّ جَاءَهُ لِلصُّبْحِ حِينَ أَسْفَرَ جِدًّا فَقَالَ قُمْ فَصَلِّ ‏.‏ فَصَلَّى الصُّبْحَ فَقَالَ ‏ "‏ مَا بَيْنَ هَذَيْنِ وَقْتٌ كُلُّهُ ‏"‏ ‏.‏\hadithno{526}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Jabir bin 'Abdullah said:"Jibril, peace be upon him, came to the Prophet (ﷺ) when the sun had passed its zenith and said: 'Get up, O Muhammad, and pray Zuhr when the sun has passed its zenith.' Then he waited until a man's shadow was equal to his height. Then he came to him for 'Asr and said: 'Get up, O Muhammad, and pray 'Asr.' Then he waited until the sunset, then he came to him and said: 'Get up, O Muhammad, and pray Maghrib.' So he got up and prayed it when the sun had set. Then he waited until the twilight disappeared, then he came to him and said: 'Get up, O Muhammad, and pray 'Isha'.' So he got up and prayed it. Then he came to him when dawn broke and said: 'Get up, O Muhammad, and pray.' So he got up and prayed Subh.' So he got up and prayed Subh. Then he came to him the next day when a man's shadow was equal to his height, and said: 'Get up, O Muhammad, and pray.' So he prayed Zuhr. Then Jibril came to him when a man's shadow was equal to twice his length and said: 'Get up, O Muhammad, and pray.' So he prayed 'Asr. Then he came to him for Maghrib when the sun set, at exactly the same time as the day before, and said: 'Get up, O Muhammad, and pray.' So he prayed Maghrib. Then he came to him for 'Isha' when the first third of the night had passed, and said: 'Get up and pray.' So he prayed 'Isha'. Then he came to him for Subh when it had become very bright, and said: 'Get up and pray.' So he prayed Subh. Then he said: 'The times of prayer one between those two (limits)}}
\hadithdefcmd{nasai}{527}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَسَنٍ، قَالَ قَدِمَ الْحَجَّاجُ فَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الظُّهْرَ بِالْهَاجِرَةِ وَالْعَصْرَ وَالشَّمْسُ بَيْضَاءُ نَقِيَّةٌ وَالْمَغْرِبَ إِذَا وَجَبَتِ الشَّمْسُ وَالْعِشَاءَ أَحْيَانًا كَانَ إِذَا رَآهُمْ قَدِ اجْتَمَعُوا عَجَّلَ وَإِذَا رَآهُمْ قَدْ أَبْطَئُوا أَخَّرَ ‏.‏\hadithno{527}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Muhammad bin 'Amr bin Hasan said:"Al-Hajjaj arrived, and we asked Jabir bin 'Abdullah, who said: 'The Messenger of Allah (ﷺ) prayed Zuhr at the time of intense heat, [1] and 'Asr when the sun was white and clear, and Maghrib when the sun set, and with 'Isha' it would depend - if he saw that the people had gathered, he would pray early, and if he saw that they had not come yet, he would delay it.'" [1] Meaning, at the earliest time}}
\hadithdefcmd{nasai}{528}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ رَقَبَةَ، عَنْ جَعْفَرِ بْنِ إِيَاسٍ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ أَنَا أَعْلَمُ النَّاسِ، بِمِيقَاتِ هَذِهِ الصَّلاَةِ عِشَاءِ الآخِرَةِ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّيهَا لِسُقُوطِ الْقَمَرِ لِثَالِثَةٍ ‏.‏\hadithno{528}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that An-Nu'man bin Bashir said:"I am the most knowledgeable of people about the time of the 'Isha' prayer. The Prophet (ﷺ) used to pray it when the moon set on the third night of the month}}
\hadithdefcmd{nasai}{529}{أَخْبَرَنَا عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ بَشِيرِ بْنِ ثَابِتٍ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ وَاللَّهِ إِنِّي لأَعْلَمُ النَّاسِ بِوَقْتِ هَذِهِ الصَّلاَةِ صَلاَةِ الْعِشَاءِ الآخِرَةِ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّيهَا لِسُقُوطِ الْقَمَرِ لِثَالِثَةٍ ‏.‏\hadithno{529}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that An-Nu'man bin Bashir said:"By Allah, I am the most knowledgeable of people about the time of the 'Isha' prayers. The Prophet (ﷺ) used to pray it when the moon set on the third night of the month}}
\hadithdefcmd{nasai}{530}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَوْفٍ، عَنْ سَيَّارِ بْنِ سَلاَمَةَ، قَالَ دَخَلْتُ أَنَا وَأَبِي، عَلَى أَبِي بَرْزَةَ الأَسْلَمِيِّ فَقَالَ لَهُ أَبِي أَخْبِرْنَا كَيْفَ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْمَكْتُوبَةَ قَالَ كَانَ يُصَلِّي الْهَجِيرَ الَّتِي تَدْعُونَهَا الأُولَى حِينَ تَدْحَضُ الشَّمْسُ وَكَانَ يُصَلِّي الْعَصْرَ ثُمَّ يَرْجِعُ أَحَدُنَا إِلَى رَحْلِهِ فِي أَقْصَى الْمَدِينَةِ وَالشَّمْسُ حَيَّةٌ قَالَ وَنَسِيتُ مَا قَالَ فِي الْمَغْرِبِ قَالَ وَكَانَ يَسْتَحِبُّ أَنْ تُؤَخَّرَ صَلاَةُ الْعِشَاءِ الَّتِي تَدْعُونَهَا الْعَتَمَةَ قَالَ وَكَانَ يَكْرَهُ النَّوْمَ قَبْلَهَا وَالْحَدِيثَ بَعْدَهَا وَكَانَ يَنْفَتِلُ مِنْ صَلاَةِ الْغَدَاةِ حِينَ يَعْرِفُ الرَّجُلُ جَلِيسَهُ وَكَانَ يَقْرَأُ بِالسِّتِّينَ إِلَى الْمِائَةِ ‏.‏\hadithno{530}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sayyar bin Salamah said:"My father and I entered upon Abu Barzah, and my father said to him: 'How did the Messenger of Allah (ﷺ) pray the prescribed prayers?' He said: He used to pray Zuhr, which you call Al-Uala (the first) when the sun passed its zenith; he used to pray 'Asr then one of us could go back to his home in the farthest part of Al-Madinah when the sun was still bright.'" - He said: "I forgot what he said to me about Maghrib." - "And he used to like to delay 'Isha', which you call Al-'Atamah, and he did not like to sleep before it nor speak after it. And he used to finish the Al-Ghadah (Fajr) prayer when a man could recognize his neighbor, and he used to recite between sixty and one hundred verses}}
\hadithdefcmd{nasai}{531}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، وَيُوسُفُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ قُلْتُ لِعَطَاءٍ أَىُّ حِينٍ أَحَبُّ إِلَيْكَ أَنْ أُصَلِّيَ الْعَتَمَةَ إِمَامًا أَوْ خِلْوًا قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ يَقُولُ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ بِالْعَتَمَةِ حَتَّى رَقَدَ النَّاسُ وَاسْتَيْقَظُوا وَرَقَدُوا وَاسْتَيْقَظُوا فَقَامَ عُمَرُ فَقَالَ الصَّلاَةَ الصَّلاَةَ قَالَ عَطَاءٌ قَالَ ابْنُ عَبَّاسٍ خَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم كَأَنِّي أَنْظُرُ إِلَيْهِ الآنَ يَقْطُرُ رَأْسُهُ مَاءً وَاضِعًا يَدَهُ عَلَى شِقِّ رَأْسِهِ قَالَ وَأَشَارَ فَاسْتَثْبَتُّ عَطَاءً كَيْفَ وَضَعَ النَّبِيُّ صلى الله عليه وسلم يَدَهُ عَلَى رَأْسِهِ فَأَوْمَأَ إِلَىَّ كَمَا أَشَارَ ابْنُ عَبَّاسٍ فَبَدَّدَ لِي عَطَاءٌ بَيْنَ أَصَابِعِهِ بِشَىْءٍ مِنْ تَبْدِيدٍ ثُمَّ وَضَعَهَا فَانْتَهَى أَطْرَافُ أَصَابِعِهِ إِلَى مُقَدَّمِ الرَّأْسِ ثُمَّ ضَمَّهَا يَمُرُّ بِهَا كَذَلِكَ عَلَى الرَّأْسِ حَتَّى مَسَّتْ إِبْهَامَاهُ طَرَفَ الأُذُنِ مِمَّا يَلِي الْوَجْهَ ثُمَّ عَلَى الصَّدْغِ وَنَاحِيَةِ الْجَبِينِ لاَ يَقْصُرُ وَلاَ يَبْطُشُ شَيْئًا إِلاَّ كَذَلِكَ ثُمَّ قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ أَنْ لاَ يُصَلُّوهَا إِلاَّ هَكَذَا ‏"‏ ‏.‏\hadithno{531}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Juraij said:"I said to 'Ata': 'What is the best time you think I should pray Al-'Atamah, either in congregation or on my own?' He said: 'I heard Ibn 'Abbas say: "The Messenger of Allah (ﷺ) delayed Al-'Atamah one night until the people had slept and woken up, then slept and woken up again. Then 'Umar got up and said: 'The prayer, the prayer!'" 'Ata' said: 'Ibn 'Abbas said: "The Messenger of Allah (ﷺ) came out, and it is as if I can see him now, with water dripping from his head, putting his hand on the side of his head. [He said: "And he indicated (how)"].'" I checked with 'Ata' how the Prophet (ﷺ) put his hand on his head, and he showed me the same way as Ibn 'Abbas had done. 'Ata' spread his fingers a little, then placed them with the tips of his fingers on his forehead, then he drew his fingers together on his head until his thumb touched the edge of the ear that is next to the face, then moved it to his temple and forehead, then he said: 'Were it not that I would impose too much difficulty for my Ummah, I would have commanded them to offer this prayer only at this time}}
\hadithdefcmd{nasai}{532}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الْمَكِّيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، وَعَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَخَّرَ النَّبِيُّ صلى الله عليه وسلم الْعِشَاءَ ذَاتَ لَيْلَةٍ حَتَّى ذَهَبَ مِنَ اللَّيْلِ فَقَامَ عُمَرُ - رضى الله عنه - فَنَادَى الصَّلاَةَ يَا رَسُولَ اللَّهِ رَقَدَ النِّسَاءُ وَالْوِلْدَانُ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمَاءُ يَقْطُرُ مِنْ رَأْسِهِ وَهُوَ يَقُولُ ‏ "‏ إِنَّهُ الْوَقْتُ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي ‏"‏ ‏.‏\hadithno{532}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Prophet (ﷺ) delayed 'Isha' one night until part of the night had passed. Then 'Umar, may Allah be pleased with him, got up and called out: 'The prayer, O Messenger of Allah! The women and children have gone to sleep.' Then the Messenger of Allah (ﷺ) came out with water dripping from his head, saying: 'This is (the best) time (for 'Isha'), were it not that this would be too difficult for my Ummah}}
\hadithdefcmd{nasai}{533}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُؤَخِّرُ الْعِشَاءَ الآخِرَةَ ‏.‏\hadithno{533}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Messenger of Allah (ﷺ) used to delay the later 'Isha'."[1] [1] It is described as the later 'Isha' prayer because the Maghrib prayer is sometimes called 'Isha' prayer, but it is the first 'Isha'. Some scholars are of the opinion that it is disliked to call Maghrib 'Isha' without qualifying it as the first 'Isha'. See Fath Al-Bari}}
\hadithdefcmd{nasai}{534}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِتَأْخِيرِ الْعِشَاءِ وَبِالسِّوَاكِ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏\hadithno{534}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Were it not that I would impose too much difficulty on my Ummah, I would have commanded them to delay 'Isha' and to use the Siwak for every prayer}}
\hadithdefcmd{nasai}{535}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا ابْنُ حِمْيَرَ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَبْلَةَ، عَنِ الزُّهْرِيِّ، وَأَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنِي أَبِي، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً بِالْعَتَمَةِ فَنَادَاهُ عُمَرُ رضى الله عنه نَامَ النِّسَاءُ وَالصِّبْيَانُ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ مَا يَنْتَظِرُهَا غَيْرُكُمْ ‏"‏ ‏.‏ وَلَمْ يَكُنْ يُصَلَّى يَوْمَئِذٍ إِلاَّ بِالْمَدِينَةِ ثُمَّ قَالَ ‏"‏ صَلُّوهَا فِيمَا بَيْنَ أَنْ يَغِيبَ الشَّفَقُ إِلَى ثُلُثِ اللَّيْلِ ‏"‏ ‏.‏ وَاللَّفْظُ لاِبْنِ حِمْيَرَ ‏.‏\hadithno{535}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) delayed A;-'Atamah one night, and 'Umar, may Allah be pleased with him, called out to him: 'The women and children have gone to sleep.' The Messenger of Allah (ﷺ) came out and said: 'No one is waiting for it except you.' At that time no prayer was offered except in Al-Madinah. Then he said: 'Pray it between the time when the twilight disappears and when one-third of the night has passed}}
\hadithdefcmd{nasai}{536}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ ح وَأَخْبَرَنِي يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي الْمُغِيرَةُ بْنُ حَكِيمٍ، عَنْ أُمِّ كُلْثُومٍ ابْنَةِ أَبِي بَكْرٍ، أَنَّهَا أَخْبَرَتْهُ عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ أَعْتَمَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ حَتَّى ذَهَبَ عَامَّةُ اللَّيْلِ وَحَتَّى نَامَ أَهْلُ الْمَسْجِدِ ثُمَّ خَرَجَ فَصَلَّى وَقَالَ ‏ "‏ إِنَّهُ لَوَقْتُهَا لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي ‏"‏ ‏.‏\hadithno{536}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah the Mother of the Believers said:"The Prophet (ﷺ) delayed the prayer one night until most of the night had passed and the people in the Masjid had gone home to sleep, then he went out and prayed, and said: 'This is indeed its (prayer) time, were it not that I would impose too much difficulty on my Ummah}}
\hadithdefcmd{nasai}{537}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَكَثْنَا ذَاتَ لَيْلَةٍ نَنْتَظِرُ رَسُولَ اللَّهِ صلى الله عليه وسلم لِعِشَاءِ الآخِرَةِ فَخَرَجَ عَلَيْنَا حِينَ ذَهَبَ ثُلُثُ اللَّيْلِ أَوْ بَعْدَهُ فَقَالَ حِينَ خَرَجَ ‏ "‏ إِنَّكُمْ تَنْتَظِرُونَ صَلاَةً مَا يَنْتَظِرُهَا أَهْلُ دِينٍ غَيْرُكُمْ وَلَوْلاَ أَنْ يَثْقُلَ عَلَى أُمَّتِي لَصَلَّيْتُ بِهِمْ هَذِهِ السَّاعَةَ ‏"‏ ‏.‏ ثُمَّ أَمَرَ الْمُؤَذِّنَ فَأَقَامَ ثُمَّ صَلَّى ‏.‏\hadithno{537}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"We stayed in the Masjid one night waiting for the Messenger of Allah (ﷺ) to pray 'Isha'. He came out to us when one-third of the night or more had passed, and he said when he came out: 'You are waiting for a prayer for which the followers of no other religion are waiting. Were it not that I would impose too much difficulty on my Ummah, I would have led them in prayer at this time.' Then he commanded the Mu'adhdhin to say the Iqamah and he prayed}}
\hadithdefcmd{nasai}{538}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْمَغْرِبِ ثُمَّ لَمْ يَخْرُجْ إِلَيْنَا حَتَّى ذَهَبَ شَطْرُ اللَّيْلِ فَخَرَجَ فَصَلَّى بِهِمْ ثُمَّ قَالَ ‏ "‏ إِنَّ النَّاسَ قَدْ صَلُّوا وَنَامُوا وَأَنْتُمْ لَمْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُ الصَّلاَةَ وَلَوْلاَ ضَعْفُ الضَّعِيفِ وَسُقْمُ السَّقِيمِ لأَمَرْتُ بِهَذِهِ الصَّلاَةِ أَنْ تُؤَخَّرَ إِلَى شَطْرِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{538}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah (ﷺ) led us in Maghrib prayer, then he did not come out to us until half the night had passed. Then he came out and led them in prayer, then he said: 'The people have prayed and gone to sleep, but you are still in a state of prayer so long as you are waiting for the prayer. Were it not for the weakness of the weak and, the sickness of the sick, I would have commanded that this prayer be delayed until halfway through the night}}
\hadithdefcmd{nasai}{539}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا خَالِدٌ، قَالاَ حَدَّثَنَا حُمَيْدٌ، قَالَ سُئِلَ أَنَسٌ هَلِ اتَّخَذَ النَّبِيُّ صلى الله عليه وسلم خَاتَمًا قَالَ نَعَمْ أَخَّرَ لَيْلَةً صَلاَةَ الْعِشَاءِ الآخِرَةِ إِلَى قَرِيبٍ مِنْ شَطْرِ اللَّيْلِ فَلَمَّا أَنْ صَلَّى أَقْبَلَ النَّبِيُّ صلى الله عليه وسلم عَلَيْنَا بِوَجْهِهِ ثُمَّ قَالَ ‏ "‏ إِنَّكُمْ لَنْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُوهَا ‏"‏ ‏.‏ قَالَ أَنَسٌ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ ‏.‏ فِي حَدِيثِ عَلِيٍّ إِلَى شَطْرِ اللَّيْلِ ‏.‏\hadithno{539}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Humaid said:"Anas was asked: 'Did the Prophet (ﷺ) use a ring?' He said: 'Yes. One night he delayed the later 'Isha' prayer, until almost halfway through the night. When he prayed the Prophet (ﷺ) turned his face toward us and said: 'You are still in a state of prayer so long as you waiting for it.'" Anas said: 'It is as if I can see the luster of his ring.' According to the narration of 'Ali - that is, Ibn Hujr - "until halfway through the night}}
\hadithdefcmd{nasai}{540}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا عَلَيْهِ لاَسْتَهَمُوا وَلَوْ يَعْلَمُ النَّاسُ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ وَلَوْ عَلِمُوا مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏ ‏.‏\hadithno{540}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"If the people knew what (virtue) there was in the call to prayer and the first row, and they not find any way to get to do that [1] other than by drawing lots, they would do that. If they knew what (virtue) there was in coming early to prayer, they would compete to be first in the Masjid. If they knew what (virtue) there was in Al-'Atamah and Subh, they would come to them even if they had to crawl." [1] Indicating the two mentioned items: that is the call to prayer and praying in the first row}}
\hadithdefcmd{nasai}{541}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، - هُوَ الْحَفَرِيُّ - عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي لَبِيدٍ، عن أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمْ هَذِهِ فَإِنَّهُمْ يُعْتِمُونَ عَلَى الإِبِلِ وَإِنَّهَا الْعِشَاءُ ‏"‏ ‏.‏\hadithno{541}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) said: 'Do not let the Bedouin make you change the name of this prayer of yours, for they delay the prayer until it is very dark because of their preoccupation with camels and milking them. Verily, it is 'Isha}}
\hadithdefcmd{nasai}{542}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنِ ابْنِ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمْ أَلاَ إِنَّهَا الْعِشَاءُ ‏"‏ ‏.‏\hadithno{542}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"I heard the Messenger of Allah (ﷺ) say on the Minbar: 'Do not let the Bedouin make you change the name of your prayer; verily, it is 'Isha}}
\hadithdefcmd{nasai}{543}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدِ بْنِ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ أَبِيهِ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الصُّبْحَ حِينَ تَبَيَّنَ لَهُ الصُّبْحُ ‏.‏\hadithno{543}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ja'far bin Muhammad bin 'Ali bin Al-Husain narrated from his father, that Jabir bin 'Abdullah said:"The Messenger of Allah (ﷺ) prayed Subh as soon as he was certain the dawn had appeared}}
\hadithdefcmd{nasai}{544}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ عَنْ وَقْتِ صَلاَةِ الْغَدَاةِ فَلَمَّا أَصْبَحْنَا مِنَ الْغَدِ أَمَرَ حِينَ انْشَقَّ الْفَجْرُ أَنْ تُقَامَ الصَّلاَةُ فَصَلَّى بِنَا فَلَمَّا كَانَ مِنَ الْغَدِ أَسْفَرَ ثُمَّ أَمَرَ فَأُقِيمَتِ الصَّلاَةُ فَصَلَّى بِنَا ثُمَّ قَالَ ‏ "‏ أَيْنَ السَّائِلُ عَنْ وَقْتِ الصَّلاَةِ مَا بَيْنَ هَذَيْنِ وَقْتٌ ‏"‏ ‏.‏\hadithno{544}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Humaid narrated from Ans that a man came to the Prophet (ﷺ) and asked him about the time of the Subh prayer. The following morning he commanded that the Iqamah for prayer be said when dawn broke, and he led us in prayer. The next day when there was light he commanded that the Iqamah for prayer be said and he led us in prayer. Then he said:"Where is the one who was asking about the time for prayer? (It is) between these two times}}
\hadithdefcmd{nasai}{545}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصَلِّي الصُّبْحَ فَيَنْصَرِفُ النِّسَاءُ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ مَا يُعْرَفْنَ مِنَ الْغَلَسِ ‏.‏\hadithno{545}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"When the Messenger of Allah (ﷺ) has prayed Subh, the women would depart, wrapped in their wrappers, unrecognizable because of the darkness}}
\hadithdefcmd{nasai}{546}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنَّ النِّسَاءُ يُصَلِّينَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الصُّبْحَ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ فَيَرْجِعْنَ فَمَا يَعْرِفْهُنَّ أَحَدٌ مِنَ الْغَلَسِ ‏.‏\hadithno{546}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The women used to pray Subh with the Messenger of Allah (ﷺ), wrapped in their wrappers, then they would return, and no one would recognize them because of the darkness}}
\hadithdefcmd{nasai}{547}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ خَيْبَرَ صَلاَةَ الصُّبْحِ بِغَلَسٍ وَهُوَ قَرِيبٌ مِنْهُمْ فَأَغَارَ عَلَيْهِمْ وَقَالَ ‏ "‏ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ - مَرَّتَيْنِ - إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏\hadithno{547}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) prayed Fajr on the day of Khaibar during the time it was still dark, when he was near the enemy. Then he attacked them and said: 'Allahu Akbar! Khaibar is destroyed!' Twice. 'Then, when it descends in their courtyard, evil will be the morning for those who had been warned!'" [1] [1] As-Saffat 37:}}
\hadithdefcmd{nasai}{548}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَجْلاَنَ، قَالَ حَدَّثَنِي عَاصِمُ بْنُ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْفِرُوا بِالْفَجْرِ ‏"‏ ‏.‏\hadithno{548}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Rafi' bin Khadij that the Prophet (ﷺ) said:"Pray Fajr when the dawn shines}}
\hadithdefcmd{nasai}{549}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رِجَالٍ، مِنْ قَوْمِهِ مِنَ الأَنْصَارِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَسْفَرْتُمْ بِالْفَجْرِ فَإِنَّهُ أَعْظَمُ بِالأَجْرِ ‏"‏ ‏.‏\hadithno{549}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Mahmud bin Labid, from some men among his people who were of the Ansar, that the Messenger of Allah (ﷺ) said:"The more you delay Fajr, the greater the reward}}
\hadithdefcmd{nasai}{550}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ الأَعْرَجُ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ سَجْدَةً مِنَ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَهَا وَمَنْ أَدْرَكَ سَجْدَةً مِنَ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَهَا ‏"‏ ‏.‏\hadithno{550}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Whoever catches up with a prostration of Subh before the sun rises, then he has caught up with it; and whoever catches up with a prostration of 'Asr before the sun sets, then he has caught up with it}}
\hadithdefcmd{nasai}{551}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ عَدِيٍّ، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الْفَجْرِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَهَا وَمَنْ أَدْرَكَ رَكْعَةً مِنَ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَهَا ‏"‏ ‏.‏\hadithno{551}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that the Prophet (ﷺ) said:"Whoever catches up with a Rak'ah of Fajr before the sun rises, then he has caught up with it; and whoever catches up with a Rak'ah of 'Asr before the sun sets, then he has caught up with it}}
\hadithdefcmd{nasai}{552}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ أَبِي صَدَقَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الظُّهْرَ إِذَا زَالَتِ الشَّمْسُ وَيُصَلِّي الْعَصْرَ بَيْنَ صَلاَتَيْكُمْ هَاتَيْنِ وَيُصَلِّي الْمَغْرِبَ إِذَا غَرَبَتِ الشَّمْسُ وَيُصَلِّي الْعِشَاءَ إِذَا غَابَ الشَّفَقُ - ثُمَّ قَالَ عَلَى إِثْرِهِ - وَيُصَلِّي الصُّبْحَ إِلَى أَنْ يَنْفَسِحَ الْبَصَرُ ‏.‏\hadithno{552}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) used to pray Zuhr when the sun passed its zenith, and he would pray 'Asr between these two prayers; and he would pray Maghrib when the sun had set, and he used to pray 'Isha' when the twilight had disappeared," then he said straight after that: "And he would pray Fajr when a man could see clearly}}
\hadithdefcmd{nasai}{553}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصَّلاَةِ رَكْعَةً فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{553}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Whoever catches up with a Rak'ah of the prayer, then he has caught up with the prayer}}
\hadithdefcmd{nasai}{554}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصَّلاَةِ رَكْعَةً فَقَدْ أَدْرَكَهَا ‏"‏ ‏.‏\hadithno{554}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Whoever catches up with a Rak'ah of the prayer, then he has caught up with it}}
\hadithdefcmd{nasai}{555}{أَخْبَرَنِي يَزِيدُ بْنُ مُحَمَّدِ بْنِ عَبْدِ الصَّمَدِ، قَالَ حَدَّثَنَا هِشَامٌ الْعَطَّارُ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ سَمَاعَةَ - عَنْ مُوسَى بْنِ أَعْيَنَ، عَنْ أَبِي عَمْرٍو الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصَّلاَةِ رَكْعَةً فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{555}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"Whoever catches up with a Rak'ah of the prayer, then he has caught up with the prayer}}
\hadithdefcmd{nasai}{556}{أَخْبَرَنِي شُعَيْبُ بْنُ شُعَيْبِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا أَبُو الْمُغِيرَةِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَدْرَكَ مِنَ الصَّلاَةِ رَكْعَةً فَقَدْ أَدْرَكَهَا ‏"‏ ‏.‏\hadithno{556}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Whoever catches up with a Rak'ah of the prayer has caught up with it}}
\hadithdefcmd{nasai}{557}{أَخْبَرَنِي مُوسَى بْنُ سُلَيْمَانَ بْنِ إِسْمَاعِيلَ بْنِ الْقَاسِمِ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ يُونُسَ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الْجُمُعَةِ أَوْ غَيْرِهَا فَقَدْ تَمَّتْ صَلاَتُهُ ‏"‏ ‏.‏\hadithno{557}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim, from his father, that the Prophet (ﷺ) said:"Whoever catches up with with a Rak'ah of Jumu'ah or any other (prayer), his prayer is complete}}
\hadithdefcmd{nasai}{558}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ التِّرْمِذِيُّ، قَالَ حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو بَكْرٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنْ صَلاَةٍ مِنَ الصَّلَوَاتِ فَقَدْ أَدْرَكَهَا إِلاَّ أَنَّهُ يَقْضِي مَا فَاتَهُ ‏"‏ ‏.‏\hadithno{558}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim that the Messenger of Allah (ﷺ) said:"Whoever catches up with a Rak'ah of one of the prayers has caught up with it, except that he has to make up the portion that he missed}}
\hadithdefcmd{nasai}{559}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ الصُّنَابِحِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّمْسُ تَطْلُعُ وَمَعَهَا قَرْنُ الشَّيْطَانِ فَإِذَا ارْتَفَعَتْ فَارَقَهَا فَإِذَا اسْتَوَتْ قَارَنَهَا فَإِذَا زَالَتْ فَارَقَهَا فَإِذَا دَنَتْ لِلْغُرُوبِ قَارَنَهَا فَإِذَا غَرَبَتْ فَارَقَهَا ‏"‏ ‏.‏ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الصَّلاَةِ فِي تِلْكَ السَّاعَاتِ ‏.‏\hadithno{559}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah As-Sunabihi that the Messenger of Allah (ﷺ) said:"The sun rises and with it the horn of the Shaitan, then when it is fully risen, he goes away. Then when it approaches the meridian he comes near to it, and when it has passed the zenith he goes away. Then when it is close to setting, he comes near to it, then when it has set, he goes away." And the Messenger of Allah (ﷺ) forbade praying at those times}}
\hadithdefcmd{nasai}{560}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ مُوسَى بْنِ عُلِيِّ بْنِ رَبَاحٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ ثَلاَثُ سَاعَاتٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَانَا أَنْ نُصَلِّيَ فِيهِنَّ أَوْ نَقْبُرَ فِيهِنَّ مَوْتَانَا حِينَ تَطْلُعُ الشَّمْسُ بَازِغَةً حَتَّى تَرْتَفِعَ وَحِينَ يَقُومُ قَائِمُ الظَّهِيرَةِ حَتَّى تَمِيلَ وَحِينَ تَضَيَّفُ الشَّمْسُ لِلْغُرُوبِ حَتَّى تَغْرُبَ ‏.‏\hadithno{560}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Musa bin 'Ali bin Rabah said:"I heard my father say: 'I heard 'Uqbah bin 'Amir Al-Juhani say: There are three times during which the Messenger of Allah (ﷺ) forbade us to pray in or bury our dead: When the sun has clearly stated to rise, until it is fully risen; when it is directly overhead at noon, until it has passed its zenith; and when it is close to setting, until it has fully set}}
\hadithdefcmd{nasai}{561}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حِبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَعَنِ الصَّلاَةِ بَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{561}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) forbade praying after 'Asr until the sun had set, and after Subh until the sun had risen}}
\hadithdefcmd{nasai}{562}{أَخْبَرَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا مَنْصُورٌ، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا أَبُو الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ غَيْرَ، وَاحِدٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ - وَكَانَ مِنْ أَحَبِّهِمْ إِلَىَّ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ وَعَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏.‏\hadithno{562}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I heard more than one of the Companions of the Prophet (ﷺ) - including 'Umar who was one of the dearest of them to me - that the Messenger of Allah (ﷺ) forbade praying after Fajr until the sun had risen, and praying after 'Asr until the sun had set}}
\hadithdefcmd{nasai}{563}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَحَرَّ أَحَدُكُمْ فَيُصَلِّيَ عِنْدَ طُلُوعِ الشَّمْسِ وَعِنْدَ غُرُوبِهَا ‏"‏ ‏.‏\hadithno{563}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:"No one of you should deliberately try to pray when the sun is rising, or when it is setting}}
\hadithdefcmd{nasai}{564}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، أَنْبَأَنَا خَالِدٌ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُصَلَّى مَعَ طُلُوعِ الشَّمْسِ أَوْ غُرُوبِهَا ‏.‏\hadithno{564}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) forbade praying when the sun is rising or setting}}
\hadithdefcmd{nasai}{565}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا سُفْيَانُ، - وَهُوَ ابْنُ حَبِيبٍ - عَنْ مُوسَى بْنِ عُلَىٍّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ، يَقُولُ ثَلاَثُ سَاعَاتٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَانَا أَنْ نُصَلِّيَ فِيهِنَّ أَوْ نَقْبُرَ فِيهِنَّ مَوْتَانَا حِينَ تَطْلُعُ الشَّمْسُ بَازِغَةً حَتَّى تَرْتَفِعَ وَحِينَ يَقُومُ قَائِمُ الظَّهِيرَةِ حَتَّى تَمِيلَ وَحِينَ تَضَيَّفُ لِلْغُرُوبِ حَتَّى تَغْرُبَ ‏.‏\hadithno{565}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Musa bin 'Ali that his father said:"I heard 'Uqbah bin 'Amir say: 'There are three times during which the Messenger of Allah (ﷺ) forbade us from praying or burying our dead: When the sun had clearly started to rise until it was fully risen, when it was directly overhead at noon until it has passed the zenith, and when it was close to setting until it had fully set}}
\hadithdefcmd{nasai}{566}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الصَّلاَةِ بَعْدَ الصُّبْحِ حَتَّى الطُّلُوعِ وَعَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى الْغُرُوبِ ‏.‏\hadithno{566}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Damrah bin Sa'eed that he heard Abu Sa'eed Al-Khudri say:"The Messenger of Allah (ﷺ) forbade praying after Subh until the sun had risen, and praying after 'Asr until the sun had set}}
\hadithdefcmd{nasai}{567}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ صَلاَةَ بَعْدَ الْفَجْرِ حَتَّى تَبْزُغَ الشَّمْسُ وَلاَ صَلاَةَ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{567}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Ata' bin Yazid that he heard Abu Sa'eed Al-Khudri say:"I heard the Messenger of Allah (ﷺ) say: 'There is no prayer after Fajr until the sun has clearly risen, and no prayer after 'Asr until the sun has fully set}}
\hadithdefcmd{nasai}{568}{أَخْبَرَنِي مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا الْوَلِيدُ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{568}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Abu Sa'eed Al-Khudri, from the Messenger of Allah (ﷺ) with a similar report}}
\hadithdefcmd{nasai}{569}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ حُجَيْرٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ ‏.‏\hadithno{569}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) forbade praying after 'Asr}}
\hadithdefcmd{nasai}{570}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ الْمُخَرِّمِيُّ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ عَنْبَسَةَ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، قَالَ قَالَتْ عَائِشَةُ رضى الله عنها أَوْهَمَ عُمَرُ - رضى الله عنه - إِنَّمَا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَتَحَرَّوْا بِصَلاَتِكُمْ طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا فَإِنَّهَا تَطْلُعُ بَيْنَ قَرْنَىْ شَيْطَانٍ ‏"‏ ‏.‏\hadithno{570}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Tawus that his father said:"'Aishah, may Allah be please with her, said: 'Umar, may Allah be please with him, is not correct, rather the Messenger of Allah (ﷺ) only prohibited, as he said: 'Do no deliberately seek to pray when the sun is rising or when it is setting, for it rises between the horns of a Shaitan}}
\hadithdefcmd{nasai}{571}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي قَالَ، أَخْبَرَنِي ابْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا طَلَعَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تُشْرِقَ وَإِذَا غَابَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَغْرُبَ ‏"‏ ‏.‏\hadithno{571}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar said:"The Messenger of Allah (ﷺ) said: 'When the edge of the sun rises, then delay prayer until it has fully risen, and when the edge of the sun starts to set, delay prayer until it has fully set}}
\hadithdefcmd{nasai}{572}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، قَالَ أَخْبَرَنِي أَبُو يَحْيَى، سُلَيْمُ بْنُ عَامِرٍ وَضَمْرَةُ بْنُ حَبِيبٍ وَأَبُو طَلْحَةَ نُعَيْمُ بْنُ زِيَادٍ قَالُوا سَمِعْنَا أَبَا أُمَامَةَ الْبَاهِلِيَّ، يَقُولُ سَمِعْتُ عَمْرَو بْنَ عَبَسَةَ، يَقُولُ قُلْتُ يَا رَسُولَ اللَّهِ هَلْ مِنْ سَاعَةٍ أَقْرَبُ مِنَ الأُخْرَى أَوْ هَلْ مِنْ سَاعَةٍ يُبْتَغَى ذِكْرُهَا قَالَ ‏ "‏ نَعَمْ إِنَّ أَقْرَبَ مَا يَكُونُ الرَّبُّ عَزَّ وَجَلَّ مِنَ الْعَبْدِ جَوْفُ اللَّيْلِ الآخِرِ فَإِنِ اسْتَطَعْتَ أَنْ تَكُونَ مِمَّنْ يَذْكُرُ اللَّهَ عَزَّ وَجَلَّ فِي تِلْكَ السَّاعَةِ فَكُنْ فَإِنَّ الصَّلاَةَ مَحْضُورَةٌ مَشْهُودَةٌ إِلَى طُلُوعِ الشَّمْسِ فَإِنَّهَا تَطْلُعُ بَيْنَ قَرْنَىِ الشَّيْطَانِ وَهِيَ سَاعَةُ صَلاَةِ الْكُفَّارِ فَدَعِ الصَّلاَةَ حَتَّى تَرْتَفِعَ قِيدَ رُمْحٍ وَيَذْهَبَ شُعَاعُهَا ثُمَّ الصَّلاَةُ مَحْضُورَةٌ مَشْهُودَةٌ حَتَّى تَعْتَدِلَ الشَّمْسُ اعْتِدَالَ الرُّمْحِ بِنِصْفِ النَّهَارِ فَإِنَّهَا سَاعَةٌ تُفْتَحُ فِيهَا أَبْوَابُ جَهَنَّمَ وَتُسْجَرُ فَدَعِ الصَّلاَةَ حَتَّى يَفِيءَ الْفَىْءُ ثُمَّ الصَّلاَةُ مَحْضُورَةٌ مَشْهُودَةٌ حَتَّى تَغِيبَ الشَّمْسُ فَإِنَّهَا تَغِيبُ بَيْنَ قَرْنَىْ شَيْطَانٍ وَهِيَ صَلاَةُ الْكُفَّارِ ‏"‏ ‏.‏\hadithno{572}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Yahya Sulaim bin 'Amir, Damrah bin Habib and Abu Talhah Nu'aim bin Ziyad said:"We heard Abu Umamah Al-Bahili say: 'I heard 'Amrah bin 'Abasah say: I said: 'O Messenger of Allah, is there any moment which brings one close to Allah than another, or any moment that should be sought out for remembering Allah? He said: 'Yes, the closest that the Lord is to His slave is in the last part of the night, so if you can be among those who remember Allah at that time, then do so. For prayer is attended and witnessed (by the angels) until the sun rises, then it rises between the two horns of the Shaitan, that is the time when the disbelievers pray, so do not pray until the sun had risen to the height of a spear and its rays have disappeared. Then prayer is attended and witness (by the angels) until the sun is directly overhead at midday, and that is the time when the gates of Hell are opened and it is stoked up. So do not pray until the shadows appear. Then prayer is attended and witnessed (by angels) until the sun sets, and it sets between the horns of a Shaitan, and that is the time when the disbelievers pray}}
\hadithdefcmd{nasai}{573}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ وَهْبِ بْنِ الأَجْدَعِ، عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ إِلاَّ أَنْ تَكُونَ الشَّمْسُ بَيْضَاءَ نَقِيَّةً مُرْتَفِعَةً ‏.‏\hadithno{573}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah (ﷺ)forbade praying after 'Asr unless the sun was still white, clear and high}}
\hadithdefcmd{nasai}{574}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي قَالَ، قَالَتْ عَائِشَةُ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم السَّجْدَتَيْنِ بَعْدَ الْعَصْرِ عِنْدِي قَطُّ ‏.‏\hadithno{574}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hisham said:"My father told me: 'Aishah said: 'The Messenger of Allah (ﷺ) never neglected to pray two Rak'ahs after 'Asr in my house}}
\hadithdefcmd{nasai}{575}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ قَالَتْ عَائِشَةُ رضى الله تعالى عنها مَا دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ الْعَصْرِ إِلاَّ صَلاَّهُمَا ‏.‏\hadithno{575}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Al-Aswad said:'Aishah said: "The Messenger of Allah (ﷺ) never entered upon me after 'Asr but he prayed them (the two Rak'ahs)}}
\hadithdefcmd{nasai}{576}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ خَالِدِ بْنِ الْحَارِثِ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ مَسْرُوقًا، وَالأَسْوَدَ، قَالاَ نَشْهَدُ عَلَى عَائِشَةَ أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ عِنْدِي بَعْدَ الْعَصْرِ صَلاَّهُمَا ‏.‏\hadithno{576}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Ishaq said:"I heard Masruq and Al-Aswad say: We bear witness that 'Aishah said: 'When the Messenger of Allah (ﷺ) was with me after 'Asr, he would pray them (these two Rak'ahs)}}
\hadithdefcmd{nasai}{577}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ صَلاَتَانِ مَا تَرَكَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي سِرًّا وَلاَ عَلاَنِيَةً رَكْعَتَانِ قَبْلَ الْفَجْرِ وَرَكْعَتَانِ بَعْدَ الْعَصْرِ ‏.‏\hadithno{577}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"There are two prayers that the Messenger of Allah (ﷺ) never neglected to pray them in my house secretly nor publicly: Two Rak'ahs before Fajr and two Rak'ahs after 'Asr}}
\hadithdefcmd{nasai}{578}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حَرْمَلَةَ، عَنْ أَبِي سَلَمَةَ، أَنَّهُ سَأَلَ عَائِشَةَ عَنِ السَّجْدَتَيْنِ اللَّتَيْنِ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّيهِمَا بَعْدَ الْعَصْرِ فَقَالَتْ إِنَّهُ كَانَ يُصَلِّيهِمَا قَبْلَ الْعَصْرِ ثُمَّ إِنَّهُ شُغِلَ عَنْهُمَا أَوْ نَسِيَهُمَا فَصَلاَّهُمَا بَعْدَ الْعَصْرِ وَكَانَ إِذَا صَلَّى صَلاَةً أَثْبَتَهَا ‏.‏\hadithno{578}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Salamah that he asked 'Aishah about the two prostrations (Rak'ahs) that the Messenger of Allah (ﷺ) used to pray after 'Asr. She said:"He used to pray them before 'Asr, but if he got distracted or forgot them, he would pray them after 'Asr, and if he did a prayer he would be constant in it}}
\hadithdefcmd{nasai}{579}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ مَعْمَرًا، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى فِي بَيْتِهَا بَعْدَ الْعَصْرِ رَكْعَتَيْنِ مَرَّةً وَاحِدَةً وَأَنَّهَا ذَكَرَتْ ذَلِكَ لَهُ فَقَالَ ‏ "‏ هُمَا رَكْعَتَانِ كُنْتُ أُصَلِّيهِمَا بَعْدَ الظُّهْرِ فَشُغِلْتُ عَنْهُمَا حَتَّى صَلَّيْتُ الْعَصْرَ ‏"‏ ‏.‏\hadithno{579}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umm Salamah that the Prophet (ﷺ) once prayed two Rak'ahs after 'Asr in her house. She asked him about that and he said:"They are two Rak'ahs that I used to pray after Zuhr, but I got distracted and forgot them until I prayed 'Asr}}
\hadithdefcmd{nasai}{580}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ شُغِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرَّكْعَتَيْنِ قَبْلَ الْعَصْرِ فَصَلاَّهُمَا بَعْدَ الْعَصْرِ ‏.‏\hadithno{580}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Umm Salamah said:"The Messenger of Allah (ﷺ) got distracted and did not pray the two Rak'ahs before 'Asr so he prayed them after 'Asr}}
\hadithdefcmd{nasai}{581}{أَخْبَرَنَا عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، قَالَ أَنْبَأَنَا أَبِي قَالَ، حَدَّثَنَا عِمْرَانُ بْنُ حُدَيْرٍ، قَالَ سَأَلْتُ لاَحِقًا عَنِ الرَّكْعَتَيْنِ، قَبْلَ غُرُوبِ الشَّمْسِ فَقَالَ كَانَ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ يُصَلِّيهِمَا فَأَرْسَلَ إِلَيْهِ مُعَاوِيَةُ مَا هَاتَانِ الرَّكْعَتَانِ عِنْدَ غُرُوبِ الشَّمْسِ فَاضْطَرَّ الْحَدِيثَ إِلَى أُمِّ سَلَمَةَ فَقَالَتْ أُمُّ سَلَمَةَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي رَكْعَتَيْنِ قَبْلَ الْعَصْرِ فَشُغِلَ عَنْهُمَا فَرَكَعَهُمَا حِينَ غَابَتِ الشَّمْسُ فَلَمْ أَرَهُ يُصَلِّيهِمَا قَبْلُ وَلاَ بَعْدُ ‏.‏\hadithno{581}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Imran bin Hudair said:"I asked Lahiq about the two Rak'ahs before sunset. He said: "Abdullah bin Az-Zubair used to pray them, and Mu'awiyah sent word to him asking: 'What are these two Rak'ahs at sunset?' He had to refer to Umm Salamah, and Umm Salamah said: 'The Messenger of Allah (ﷺ) used to pray two Rak'ahs before 'Asr, then he was distracted and did not pray them, so he prayed them when the sun set, and I never saw him pray them before or after that}}
\hadithdefcmd{nasai}{582}{أَخْبَرَنَا عَلِيُّ بْنُ عُثْمَانَ بْنِ مُحَمَّدِ بْنِ سَعِيدِ بْنِ عَبْدِ اللَّهِ بْنِ نُفَيْلٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ أَبَا الْخَيْرِ، حَدَّثَهُ أَنَّ أَبَا تَمِيمٍ الْجَيْشَانِيَّ قَامَ لِيَرْكَعَ رَكْعَتَيْنِ قَبْلَ الْمَغْرِبِ فَقُلْتُ لِعُقْبَةَ بْنِ عَامِرٍ انْظُرْ إِلَى هَذَا أَىَّ صَلاَةٍ يُصَلِّي فَالْتَفَتَ إِلَيْهِ فَرَآهُ فَقَالَ هَذِهِ صَلاَةٌ كُنَّا نُصَلِّيهَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{582}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Yazid bin Abi Habib that Abu Al-Khair told him:"Abu Tamim Al-Jaishani stood up to pray two Rak'ahs before Maghrib, and I said to 'Uqbah bin 'Amir: 'Look at this man, what prayer is he praying?' He turned and looked at him, and said: 'This is a prayer that we used to pray at the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{583}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ زَيْدِ بْنِ مُحَمَّدٍ، قَالَ سَمِعْتُ نَافِعًا، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا طَلَعَ الْفَجْرُ لاَ يُصَلِّي إِلاَّ رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{583}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Umar that Hafsah said:"When the dawn appears, the Messenger of Allah (ﷺ) would only pray two short Rak'ahs}}
\hadithdefcmd{nasai}{584}{أَخْبَرَنِي الْحَسَنُ بْنُ إِسْمَاعِيلَ بْنِ سُلَيْمَانَ، وَأَيُّوبُ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ أَيُّوبُ حَدَّثَنَا وَقَالَ، حَسَنٌ أَخْبَرَنِي شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ يَزِيدَ بْنِ طَلْقٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ عَمْرِو بْنِ عَبَسَةَ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ مَنْ أَسْلَمَ مَعَكَ قَالَ ‏"‏ حُرٌّ وَعَبْدٌ ‏"‏ ‏.‏ قُلْتُ هَلْ مِنْ سَاعَةٍ أَقْرَبُ إِلَى اللَّهِ عَزَّ وَجَلَّ مِنْ أُخْرَى قَالَ ‏"‏ نَعَمْ جَوْفُ اللَّيْلِ الآخِرُ فَصَلِّ مَا بَدَا لَكَ حَتَّى تُصَلِّيَ الصُّبْحَ ثُمَّ انْتَهِ حَتَّى تَطْلُعَ الشَّمْسُ وَمَا دَامَتْ ‏"‏ ‏.‏ وَقَالَ أَيُّوبُ فَمَا دَامَتْ ‏"‏ كَأَنَّهَا حَجَفَةٌ حَتَّى تَنْتَشِرَ ثُمَّ صَلِّ مَا بَدَا لَكَ حَتَّى يَقُومَ الْعَمُودُ عَلَى ظِلِّهِ ثُمَّ انْتَهِ حَتَّى تَزُولَ الشَّمْسُ فَإِنَّ جَهَنَّمَ تُسْجَرُ نِصْفَ النَّهَارِ ثُمَّ صَلِّ مَا بَدَا لَكَ حَتَّى تُصَلِّيَ الْعَصْرَ ثُمَّ انْتَهِ حَتَّى تَغْرُبَ الشَّمْسُ فَإِنَّهَا تَغْرُبُ بَيْنَ قَرْنَىْ شَيْطَانٍ وَتَطْلُعُ بَيْنَ قَرْنَىْ شَيْطَانٍ ‏"‏ ‏.‏\hadithno{584}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Amr bin 'Abasah said:"I came to the Messenger of Allah, who became Muslim with you?' He said: 'Free men and slaves.' I said: 'Is there any moment which brings one closer to Allah than another?' He said: 'Yes, the last part of the night, so pray as much as you want until you pray Subh, then stop until the sun has risen until and it looks like a shield and (its shinning)spreads. Then pray as much as you want until an object's shadow is at its shortest, then stop until the sun passes its zenith, for Hell is stoked at midday. Then pray 'Asr, then stop until you pray 'Asr, then stop until the sun has set, for it sets between the horns of a Shaitan and rises between the horns of a Shaitan.'" [1] [1] Similar has been recorded by Muslim}}
\hadithdefcmd{nasai}{585}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ مِنْ أَبِي الزُّبَيْرِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ بَابَاهْ، يُحَدِّثُ عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَا بَنِي عَبْدِ مَنَافٍ لاَ تَمْنَعُوا أَحَدًا طَافَ بِهَذَا الْبَيْتِ وَصَلَّى أَيَّةَ سَاعَةٍ شَاءَ مِنْ لَيْلٍ أَوْ نَهَارٍ ‏"‏ ‏.‏\hadithno{585}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jubair bin Mut'im that the Prophet (ﷺ) said:"O Banu 'Abd Manaf, do not prevent anyone from circumambulating this House and praying at any time he wants of night or day}}
\hadithdefcmd{nasai}{586}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا مُفَضَّلٌ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ارْتَحَلَ قَبْلَ أَنْ تَزِيغَ الشَّمْسُ أَخَّرَ الظُّهْرَ إِلَى وَقْتِ الْعَصْرِ ثُمَّ نَزَلَ فَجَمَعَ بَيْنَهُمَا فَإِنْ زَاغَتِ الشَّمْسُ قَبْلَ أَنْ يَرْتَحِلَ صَلَّى الظُّهْرَ ثُمَّ رَكِبَ ‏.‏\hadithno{586}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"If the Messenger of Allah (ﷺ) was setting out on a journey before the sun passed its zenith, he would delay Zuhr until the time of 'Asr, then he would stop and combine the prayer. If the sun passed its zenith before he set out, he would pray Zuhr and then set off}}
\hadithdefcmd{nasai}{587}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ أَبِي الطُّفَيْلِ، عَامِرِ بْنِ وَاثِلَةَ أَنَّ مُعَاذَ بْنَ جَبَلٍ، أَخْبَرَهُ أَنَّهُمْ، خَرَجُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ تَبُوكَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْمَعُ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ فَأَخَّرَ الصَّلاَةَ يَوْمًا ثُمَّ خَرَجَ فَصَلَّى الظُّهْرَ وَالْعَصْرَ جَمِيعًا ثُمَّ دَخَلَ ثُمَّ خَرَجَ فَصَلَّى الْمَغْرِبَ وَالْعِشَاءَ ‏.‏\hadithno{587}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu At-Tufail 'Amir bin Wathilah that Mu'adh bin Jabal told him that they went out with the Messenger of Allah (ﷺ) in the year of Tabuk, and the Messenger of Allah (ﷺ) was joining Zuhr and 'Asr, and Maghrib and 'Isha'. He delayed the prayer one day then he went out and prayed Zuhr and 'Asr together, then he went in and came out again and prayed Maghrib and 'Isha}}
\hadithdefcmd{nasai}{588}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا كَثِيرُ بْنُ قَارَوَنْدَا، قَالَ سَأَلْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ عَنْ صَلاَةِ، أَبِيهِ فِي السَّفَرِ وَسَأَلْنَاهُ هَلْ كَانَ يَجْمَعُ بَيْنَ شَىْءٍ مِنْ صَلاَتِهِ فِي سَفَرِهِ فَذَكَرَ أَنَّ صَفِيَّةَ بِنْتَ أَبِي عُبَيْدٍ كَانَتْ تَحْتَهُ فَكَتَبَتْ إِلَيْهِ وَهُوَ فِي زَرَّاعَةٍ لَهُ أَنِّي فِي آخِرِ يَوْمٍ مِنْ أَيَّامِ الدُّنْيَا وَأَوَّلِ يَوْمٍ مِنَ الآخِرَةِ ‏.‏ فَرَكِبَ فَأَسْرَعَ السَّيْرَ إِلَيْهَا حَتَّى إِذَا حَانَتْ صَلاَةُ الظُّهْرِ قَالَ لَهُ الْمُؤَذِّنُ الصَّلاَةَ يَا أَبَا عَبْدِ الرَّحْمَنِ ‏.‏ فَلَمْ يَلْتَفِتْ حَتَّى إِذَا كَانَ بَيْنَ الصَّلاَتَيْنِ نَزَلَ فَقَالَ أَقِمْ فَإِذَا سَلَّمْتُ فَأَقِمْ ‏.‏ فَصَلَّى ثُمَّ رَكِبَ حَتَّى غَابَتِ الشَّمْسُ قَالَ لَهُ الْمُؤَذِّنُ الصَّلاَةَ ‏.‏ فَقَالَ كَفِعْلِكَ فِي صَلاَةِ الظُّهْرِ وَالْعَصْرِ ‏.‏ ثُمَّ سَارَ حَتَّى إِذَا اشْتَبَكَتِ النُّجُومُ نَزَلَ ثُمَّ قَالَ لِلْمُؤَذِّنِ أَقِمْ فَإِذَا سَلَّمْتُ فَأَقِمْ ‏.‏ فَصَلَّى ثُمَّ انْصَرَفَ فَالْتَفَتَ إِلَيْنَا فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَضَرَ أَحَدَكُمُ الأَمْرُ الَّذِي يَخَافُ فَوْتَهُ فَلْيُصَلِّ هَذِهِ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{588}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin Qarawanda said:"I asked Salim bin 'Abdullah about how his father prayed when traveling. We asked him: 'Did he combine any of his prayers when traveling?' He said that Safiyyah bint Abi 'Ubaid was married to him, and she wrote to him, when he was at some farmland of his, saying: 'This is the last of my days in this world, and the first day of the Hereafter." [1] He rode quickly to go to her, and when the time for Zuhr came, the Mu'adhdhin said to him: "The prayer, O Abu 'Abdur-Rahman!" But he paid no attention to him until it was between the time for the two prayers, then he stopped and said: "Say the Iqamah and when I say the Taslim, say the Iqamah." Then he rode on again, and when the sun set the Mu'adhdhin said to him; "The prayer!" He said: "Do as you did for Zuhr and 'Asr." When the stars had appeared, he stopped and said to the Mu'adhdhin: "Say the Iqamah and when I say the Taslim, say the Iqamah." He prayed, then when he had finished he turned to us and said: "The Messenger of Allah (ﷺ) said: 'If any one of you has an urgent need that he fears he may miss, let him pray like this.'" [1] Meaning that she was dying}}
\hadithdefcmd{nasai}{589}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ ثَمَانِيًا جَمِيعًا وَسَبْعًا جَمِيعًا أَخَّرَ الظُّهْرَ وَعَجَّلَ الْعَصْرَ وَأَخَّرَ الْمَغْرِبَ وَعَجَّلَ الْعِشَاءَ ‏.‏\hadithno{589}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I prayed with the Prophet (ﷺ) in Al-Madinah, eight together and seven together. He delayed Zuhr and brought 'Asr forward, and he delayed Maghrib and brought 'Isha' forward}}
\hadithdefcmd{nasai}{590}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ قَالَ حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا حَبِيبٌ، - وَهُوَ ابْنُ أَبِي حَبِيبٍ - عَنْ عَمْرِو بْنِ هَرِمٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ صَلَّى بِالْبَصْرَةِ الأُولَى وَالْعَصْرَ لَيْسَ بَيْنَهُمَا شَىْءٌ وَالْمَغْرِبَ وَالْعِشَاءَ لَيْسَ بَيْنَهُمَا شَىْءٌ فَعَلَ ذَلِكَ مِنْ شُغْلٍ وَزَعَمَ ابْنُ عَبَّاسٍ أَنَّهُ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ الأُولَى وَالْعَصْرَ ثَمَانِ سَجَدَاتٍ لَيْسَ بَيْنَهُمَا شَىْءٌ ‏.‏\hadithno{590}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that he prayed Al-Uula (Zuhr) and 'Asr together in Al-Basrah with nothing in between them, and he prayed Maghrib and 'Isha' together with nothing in between them. He did that because he was busy and Ibn 'Abbas said that he had prayed Zuhr and 'Isha' together with the Messenger of Allah (ﷺ) in Al-Madinah, eight Rak'ahs with nothing in between}}
\hadithdefcmd{nasai}{591}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ الرَّحْمَنِ، - شَيْخٌ مِنْ قُرَيْشٍ - قَالَ صَحِبْتُ ابْنَ عُمَرَ إِلَى الْحِمَى فَلَمَّا غَرَبَتِ الشَّمْسُ هِبْتُ أَنْ أَقُولَ لَهُ الصَّلاَةَ فَسَارَ حَتَّى ذَهَبَ بَيَاضُ الأُفُقِ وَفَحْمَةُ الْعِشَاءِ ثُمَّ نَزَلَ فَصَلَّى الْمَغْرِبَ ثَلاَثَ رَكَعَاتٍ ثُمَّ صَلَّى رَكْعَتَيْنِ عَلَى إِثْرِهَا ثُمَّ قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{591}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Isma'il bin 'Abdur-Rahman, a Shaikh of the Quraish, said:"I accompanied Ibn 'Umar to Al-Hima. [1] When the sun set I felt too nervous to remind him of the prayer, so he went on until the light on the horizon had disappeared and it was getting dark, then he stopped and prayed Maghrib, three Rak'ahs, then he prayed two Rak'ahs immediately afterwards, then he said: 'This what I saw the Messenger of Allah (ﷺ) do.'" [1] A place near Madinah}}
\hadithdefcmd{nasai}{592}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنِ ابْنِ أَبِي حَمْزَةَ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ، - وَاللَّفْظُ لَهُ - عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا أَعْجَلَهُ السَّيْرُ فِي السَّفَرِ يُؤَخِّرُ صَلاَةَ الْمَغْرِبِ حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ الْعِشَاءِ ‏.‏\hadithno{592}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Az-Zuhri said:"Salim told me that his father said: 'I saw the Messenger of Allah (ﷺ), when he was in a hurry to travel, delaying Maghrib so that he could combine it with 'Isha}}
\hadithdefcmd{nasai}{593}{أَخْبَرَنَا الْمُؤَمَّلُ بْنُ إِهَابٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ مُحَمَّدٍ الْجَارِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ غَابَتِ الشَّمْسُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ فَجَمَعَ بَيْنَ الصَّلاَتَيْنِ بِسَرِفَ ‏.‏\hadithno{593}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:"The sun set when the Messenger of Allah (ﷺ) was in Makkah, and he joined the two prayers in Sarif.: [1] [1] A valley about 12 km northeast of Makkah on the way to Al-Madinah}}
\hadithdefcmd{nasai}{594}{أَخْبَرَنِي عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنَا جَابِرُ بْنُ إِسْمَاعِيلَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ إِذَا عَجِلَ بِهِ السَّيْرُ يُؤَخِّرُ الظُّهْرَ إِلَى وَقْتِ الْعَصْرِ فَيَجْمَعُ بَيْنَهُمَا وَيُؤَخِّرُ الْمَغْرِبَ حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ الْعِشَاءِ حِينَ يَغِيبُ الشَّفَقُ ‏.‏\hadithno{594}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:"If the Messenger of Allah (ﷺ) wanted to travel quickly, he would delay Zuhr until the time of 'Asr and combine them, and he would delay Maghrib until he combined it with 'Isha' when the twilight had disappeared}}
\hadithdefcmd{nasai}{595}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا ابْنُ جَابِرٍ، قَالَ حَدَّثَنِي نَافِعٌ، قَالَ خَرَجْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ فِي سَفَرٍ يُرِيدُ أَرْضًا لَهُ فَأَتَاهُ آتٍ فَقَالَ إِنَّ صَفِيَّةَ بِنْتَ أَبِي عُبَيْدٍ لَمَا بِهَا فَانْظُرْ أَنْ تُدْرِكَهَا ‏.‏ فَخَرَجَ مُسْرِعًا وَمَعَهُ رَجُلٌ مِنْ قُرَيْشٍ يُسَايِرُهُ وَغَابَتِ الشَّمْسُ فَلَمْ يُصَلِّ الصَّلاَةَ وَكَانَ عَهْدِي بِهِ وَهُوَ يُحَافِظُ عَلَى الصَّلاَةِ فَلَمَّا أَبْطَأَ قُلْتُ الصَّلاَةَ يَرْحَمُكَ اللَّهُ ‏.‏ فَالْتَفَتَ إِلَىَّ وَمَضَى حَتَّى إِذَا كَانَ فِي آخِرِ الشَّفَقِ نَزَلَ فَصَلَّى الْمَغْرِبَ ثُمَّ أَقَامَ الْعِشَاءَ وَقَدْ تَوَارَى الشَّفَقُ فَصَلَّى بِنَا ثُمَّ أَقْبَلَ عَلَيْنَا فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا عَجِلَ بِهِ السَّيْرُ صَنَعَ هَكَذَا ‏.‏\hadithno{595}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi' said:"I went out with 'Abdullah bin 'Umar on a journey to some of his land. Then someone came to him and said: 'Safiyyah bint Abi 'Ubaid is sick, try to get there before it is too late.' He set out quickly, accompanied by a man of the Quraish. The sun set but he did not pray, although I knew him to be very careful about praying on time. When he slowed down I said: 'The prayer, may Allah have mercy on you.' He turned to me but carried on until the twilight was almost gone, then he stopped and prayed Maghrib, then he said the Iqamah for 'Isha', at that time the twilight had totally disappeared and led us in prayer. Then he turned to us and said: 'If the Messenger of Allah (ﷺ) was in a hurry to travel he would do this}}
\hadithdefcmd{nasai}{596}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْعَطَّافُ، عَنْ نَافِعٍ، قَالَ أَقْبَلْنَا مَعَ ابْنِ عُمَرَ مِنْ مَكَّةَ فَلَمَّا كَانَ تِلْكَ اللَّيْلَةُ سَارَ بِنَا حَتَّى أَمْسَيْنَا فَظَنَنَّا أَنَّهُ نَسِيَ الصَّلاَةَ فَقُلْنَا لَهُ الصَّلاَةَ ‏.‏ فَسَكَتَ وَسَارَ حَتَّى كَادَ الشَّفَقُ أَنْ يَغِيبَ ثُمَّ نَزَلَ فَصَلَّى وَغَابَ الشَّفَقُ فَصَلَّى الْعِشَاءَ ثُمَّ أَقْبَلَ عَلَيْنَا فَقَالَ هَكَذَا كُنَّا نَصْنَعُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا جَدَّ بِهِ السَّيْرُ ‏.‏\hadithno{596}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nafi' said:"We came back with Ibn 'Umar from Makkah. One night he kept on travelling until evening came, and we thought that he had forgotten the prayer!' But he kept quiet and kept going until the twilight had almost disappeared, then he stopped and prayed, and when the twilight disappeared he prayed 'Isha'. Then he turned to us and said: This is what we used to do with the Messenger of Allah (ﷺ) if he was in a hurry to travel}}
\hadithdefcmd{nasai}{597}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنَا ابْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا كَثِيرُ بْنُ قَارَوَنْدَا، قَالَ سَأَلْنَا سَالِمَ بْنَ عَبْدِ اللَّهِ عَنِ الصَّلاَةِ، فِي السَّفَرِ فَقُلْنَا أَكَانَ عَبْدُ اللَّهِ يَجْمَعُ بَيْنَ شَىْءٍ مِنَ الصَّلَوَاتِ فِي السَّفَرِ فَقَالَ لاَ إِلاَّ بِجَمْعٍ ثُمَّ أَتَيْتُهُ فَقَالَ كَانَتْ عِنْدَهُ صَفِيَّةُ فَأَرْسَلَتْ إِلَيْهِ أَنِّي فِي آخِرِ يَوْمٍ مِنَ الدُّنْيَا وَأَوَّلِ يَوْمٍ مِنَ الآخِرَةِ ‏.‏ فَرَكِبَ وَأَنَا مَعَهُ فَأَسْرَعَ السَّيْرَ حَتَّى حَانَتِ الصَّلاَةُ فَقَالَ لَهُ الْمُؤَذِّنُ الصَّلاَةَ يَا أَبَا عَبْدِ الرَّحْمَنِ ‏.‏ فَسَارَ حَتَّى إِذَا كَانَ بَيْنَ الصَّلاَتَيْنِ نَزَلَ فَقَالَ لِلْمُؤَذِّنِ أَقِمْ فَإِذَا سَلَّمْتُ مِنَ الظُّهْرِ فَأَقِمْ مَكَانَكَ ‏.‏ فَأَقَامَ فَصَلَّى الظُّهْرَ رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ أَقَامَ مَكَانَهُ فَصَلَّى الْعَصْرَ رَكْعَتَيْنِ ثُمَّ رَكِبَ فَأَسْرَعَ السَّيْرَ حَتَّى غَابَتِ الشَّمْسُ فَقَالَ لَهُ الْمُؤَذِّنُ الصَّلاَةَ يَا أَبَا عَبْدِ الرَّحْمَنِ ‏.‏ فَقَالَ كَفِعْلِكَ الأَوَّلِ ‏.‏ فَسَارَ حَتَّى إِذَا اشْتَبَكَتِ النُّجُومُ نَزَلَ فَقَالَ أَقِمْ فَإِذَا سَلَّمْتُ فَأَقِمْ ‏.‏ فَصَلَّى الْمَغْرِبَ ثَلاَثًا ثُمَّ أَقَامَ مَكَانَهُ فَصَلَّى الْعِشَاءَ الآخِرَةَ ثُمَّ سَلَّمَ وَاحِدَةً تِلْقَاءَ وَجْهِهِ ثُمَّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا حَضَرَ أَحَدَكُمْ أَمْرٌ يَخْشَى فَوْتَهُ فَلْيُصَلِّ هَذِهِ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{597}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Kathir bin Qarawanda said:"We asked Salim bin 'Abdullah about prayer while traveling. We said: 'Did 'Abdullah combine any of his prayer while traveling?' He said: 'No, except at Jam'.'[1] Then he paused, and said: 'Safiyyah was married to him, and she sent word to him that she was in her last day in this world and the first day in the Hereafter. So he ride off in a hurry, and I was with him. The time for prayer came and the Mu'adhdhin said to him: 'The prayer, O Abu 'Abdur-Rahman! But he kept going until it was between the time for the two prayer. Then he stopped and said to the Mu'adhdhin: "Say the Iqamah, and when I say the Taslim at the end of Zuhr, say the Iqamah (again) straight away." So he said the Iqamah and he prayed Zuhr, two Rak'ahs, then he said the Iqamah (again) straight away, and he prayed 'Asr, two Rak'ahs. Then he rode off quickly until the sun set and the Mu'adhdhin said to him: "The prayer, O Abu 'Abdur-Rahman!" He said: "Do what you did before." He rode on until the starts appeared, then he stopped and said: "Say the Iqamah, then when I say the Taslim, say the Iqamah. So he said the Iqamah and he prayed Maghrib, three Rak'ahs, then he said the Iqamah (again) straight away and he prayed 'Isha', then he said one Taslim, turning his face. Then he said: "The Messenger of Allah (ﷺ) said: 'If any one of you has urgent need that he fears he may miss, let him pray like this}}
\hadithdefcmd{nasai}{598}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا جَدَّ بِهِ السَّيْرُ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{598}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that if the Messenger of Allah (ﷺ) was in a hurry to travel, he would combine Maghrib and 'Isha}}
\hadithdefcmd{nasai}{599}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا جَدَّ بِهِ السَّيْرُ أَوْ حَزَبَهُ أَمْرٌ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{599}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"If the Messenger of Allah (ﷺ) was in a hurry to travel, or some emergency arose, he would combine Maghrib and 'Isha}}
\hadithdefcmd{nasai}{600}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم إِذَا جَدَّ بِهِ السَّيْرُ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{600}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sufyan said:"I heard Az-Zuhri say: 'Salim told me that his father said: 'I saw the Prophet (ﷺ), if he was in a hurry to travel, joining Maghrib and 'Isha}}
\hadithdefcmd{nasai}{601}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ وَالْعَصْرَ جَمِيعًا وَالْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا مِنْ غَيْرِ خَوْفٍ وَلاَ سَفَرٍ ‏.‏\hadithno{601}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) prayed Zuhr and 'Asr together, and Maghrib and 'Isha' together, when there was no fear and he was not traveling}}
\hadithdefcmd{nasai}{602}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، - وَاسْمُهُ غَزْوَانُ - قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي بِالْمَدِينَةِ يَجْمَعُ بَيْنَ الصَّلاَتَيْنِ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ مِنْ غَيْرِ خَوْفٍ وَلاَ مَطَرٍ ‏.‏ قِيلَ لَهُ لِمَ قَالَ لِئَلاَّ يَكُونَ عَلَى أُمَّتِهِ حَرَجٌ ‏.‏\hadithno{602}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) used to pray in Al-Madinah combining two prayer. Joining Zuhr and 'Asr, and Maghrib and 'Isha', when there was no fear nor rain. It was said to him:"Why?" He said: "So that there would not be any hardship on his Ummah}}
\hadithdefcmd{nasai}{603}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّيْتُ وَرَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَمَانِيًا جَمِيعًا وَسَبْعًا جَمِيعًا ‏.‏\hadithno{603}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"I prayed behind the Messenger of Allah (ﷺ) eight (Rak'ahs) together and seven (Rak'ahs) together}}
\hadithdefcmd{nasai}{604}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ سَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَى عَرَفَةَ فَوَجَدَ الْقُبَّةَ قَدْ ضُرِبَتْ لَهُ بِنَمِرَةَ فَنَزَلَ بِهَا حَتَّى إِذَا زَاغَتِ الشَّمْسُ أَمَرَ بِالْقَصْوَاءِ فَرُحِّلَتْ لَهُ حَتَّى إِذَا انْتَهَى إِلَى بَطْنِ الْوَادِي خَطَبَ النَّاسَ ثُمَّ أَذَّنَ بِلاَلٌ ثُمَّ أَقَامَ فَصَلَّى الظُّهْرَ ثُمَّ أَقَامَ فَصَلَّى الْعَصْرَ وَلَمْ يُصَلِّ بَيْنَهُمَا شَيْئًا ‏.‏\hadithno{604}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ja'far bin Muhammad narrated from his father that Jabir bin 'Abdullah said:"The Messenger of Allah (ﷺ) traveled until he came to 'Arafah, where he found that the tent had pitched for him. He stayed there until the sun had passed its zenith, then he called for Al-Qaswa' which was saddled for him. When he reached the bottom of the valley he addressed the people. Then Bilal called the Adhan, then the Iqamah, then he prayed Zuhr, then he called the Iqamah, then he prayed 'Asr, and he did not offer any other prayer in between}}
\hadithdefcmd{nasai}{605}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، أَنَّ أَبَا أَيُّوبَ الأَنْصَارِيَّ، أَخْبَرَهُ أَنَّهُ، صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ جَمِيعًا ‏.‏\hadithno{605}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin Yazid that Abu Ayyub Al-Ansari told him, that during the Farewell Pilgrimage. He prayed with the Messenger of Allah (ﷺ) Maghrib and 'Isha' prayers together at Al-Muzdalifah}}
\hadithdefcmd{nasai}{606}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ كُنْتُ مَعَ ابْنِ عُمَرَ حَيْثُ أَفَاضَ مِنْ عَرَفَاتٍ فَلَمَّا أَتَى جَمْعًا جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ فَلَمَّا فَرَغَ قَالَ فَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي هَذَا الْمَكَانِ مِثْلَ هَذَا ‏.‏\hadithno{606}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"I was with Ibn 'Umar when he departed from 'Arafah. When he came to Jam' (Al-Muzdalifah), he combined Maghrib and 'Isha', and when he finished he said: 'The Messenger of Allah (ﷺ) did similar to this in this place}}
\hadithdefcmd{nasai}{607}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ ‏.‏\hadithno{607}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet (ﷺ) prayed Maghrib and 'Isha' at Al-Muzdalifah}}
\hadithdefcmd{nasai}{608}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم جَمَعَ بَيْنَ صَلاَتَيْنِ إِلاَّ بِجَمْعٍ وَصَلَّى الصُّبْحَ يَوْمَئِذٍ قَبْلَ وَقْتِهَا ‏.‏\hadithno{608}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"I never saw the Messenger of Allah (ﷺ) combine any two prayers except in Al-Muzdalifah, and on that day he prayed Subh before its time}}
\hadithdefcmd{nasai}{609}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، وَمُحَمَّدُ بْنُ أَبِي حَرْمَلَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، وَكَانَ النَّبِيُّ، صلى الله عليه وسلم أَرْدَفَهُ مِنْ عَرَفَةَ فَلَمَّا أَتَى الشِّعْبَ نَزَلَ فَبَالَ وَلَمْ يَقُلْ أَهْرَاقَ الْمَاءَ قَالَ فَصَبَبْتُ عَلَيْهِ مِنْ إِدَاوَةٍ فَتَوَضَّأَ وُضُوءًا خَفِيفًا ‏.‏ فَقُلْتُ لَهُ الصَّلاَةَ ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَلَمَّا أَتَى الْمُزْدَلِفَةَ صَلَّى الْمَغْرِبَ ثُمَّ نَزَعُوا رِحَالَهُمْ ثُمَّ صَلَّى الْعِشَاءَ ‏.‏\hadithno{609}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Usamah bin Zaid, whom the Prophet (ﷺ) had seated behind him on his camel on the way from 'Arafah, that when he reached the mountain pass, he dismounted and urinated - and he did not say that he passed water. He (Usamah) said:"I poured water for him from a small vessel and he performed a light Wudu'. I said to him: 'The prayer.' He said: 'The prayer is still ahead of you.' When he came to Al-Muzdalifah he prayed Maghrib, then they untied the saddles of their mounts and then he prayed 'Isha}}
\hadithdefcmd{nasai}{610}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي الْوَلِيدُ بْنُ الْعَيْزَارِ، قَالَ سَمِعْتُ أَبَا عَمْرٍو الشَّيْبَانِيَّ، يَقُولُ حَدَّثَنَا صَاحِبُ، هَذِهِ الدَّارِ وَأَشَارَ إِلَى دَارِ عَبْدِ اللَّهِ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ الْعَمَلِ أَحَبُّ إِلَى اللَّهِ تَعَالَى قَالَ ‏ "‏ الصَّلاَةُ عَلَى وَقْتِهَا وَبِرُّ الْوَالِدَيْنِ وَالْجِهَادُ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{610}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Walid bin Al'Ayzar said:"I heard Abu 'Amr Ash-Shaibani say: 'The owner of this house - and he pointed to the house of 'Abdullah - said: I asked the Messenger of Allah (ﷺ): 'Which deed is most beloved to Allah, may He be exalted?' He said: 'Prayer offered on time, honoring one's parents, and Jihad in the cause of Allah}}
\hadithdefcmd{nasai}{611}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ النَّخَعِيُّ، سَمِعَهُ مِنْ أَبِي عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ الْعَمَلِ أَحَبُّ إِلَى اللَّهِ عَزَّ وَجَلَّ قَالَ ‏ "‏ إِقَامُ الصَّلاَةِ لِوَقْتِهَا وَبِرُّ الْوَالِدَيْنِ وَالْجِهَادُ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{611}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"I asked the Messenger of Allah (ﷺ) which action is most beloved to Allah? He said: 'Establishing prayer on time, honoring one's parents and Jihad in the cause of Allah}}
\hadithdefcmd{nasai}{612}{أَخْبَرَنَا يَحْيَى بْنُ حَكِيمٍ، وَعَمْرُو بْنُ يَزِيدَ، قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ فِي مَسْجِدِ عَمْرِو بْنِ شُرَحْبِيلَ فَأُقِيمَتِ الصَّلاَةُ فَجَعَلُوا يَنْتَظِرُونَهُ فَقَالَ إِنِّي كُنْتُ أُوتِرُ ‏.‏ قَالَ وَسُئِلَ عَبْدُ اللَّهِ هَلْ بَعْدَ الأَذَانِ وِتْرٌ قَالَ نَعَمْ وَبَعْدَ الإِقَامَةِ وَحَدَّثَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَامَ عَنِ الصَّلاَةِ حَتَّى طَلَعَتِ الشَّمْسُ ثُمَّ صَلَّى ‏.‏ وَاللَّفْظُ لِيَحْيَى ‏.‏\hadithno{612}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibrahim bin Muhammad bin Al-Muntashir that his father was in the Masjid of 'Amr bin Shurahbil and the Iqamah for prayer was said, so they were waiting for him. He said:"I was praying Witr, and 'Abdullah was asked: 'Is there any Witr after the Adhan?' He said: "Yes, and after the Iqamah, and he narrated that the Prophet (ﷺ) slept and missed the prayer until the sun rose then prayed.'" And the wording is that of Yahya}}
\hadithdefcmd{nasai}{613}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏\hadithno{613}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:The Messenger of Allah (ﷺ) said: "Whoever forgets a prayer, let him pray it when he remembers it}}
\hadithdefcmd{nasai}{614}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ يَزِيدَ، قَالَ حَدَّثَنَا حَجَّاجٌ الأَحْوَلُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ يَرْقُدُ عَنِ الصَّلاَةِ أَوْ يَغْفُلُ عَنْهَا قَالَ ‏ "‏ كَفَّارَتُهَا أَنْ يُصَلِّيَهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏\hadithno{614}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) was asked about a man who slept and missed the prayer, or forgot it. He said: 'The expiation for that is to pray it when he remembers it}}
\hadithdefcmd{nasai}{615}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، قَالَ ذَكَرُوا لِلنَّبِيِّ صلى الله عليه وسلم نَوْمَهُمْ عَنِ الصَّلاَةِ فَقَالَ ‏ "‏ إِنَّهُ لَيْسَ فِي النَّوْمِ تَفْرِيطٌ إِنَّمَا التَّفْرِيطُ فِي الْيَقَظَةِ فَإِذَا نَسِيَ أَحَدُكُمْ صَلاَةً أَوْ نَامَ عَنْهَا فَلْيُصَلِّهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏\hadithno{615}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Qatadah said:"They told the Prophet (ﷺ) that they had slept and missed the prayer. He said: 'There is no negligence when one sleeps, rather negligence is when one is awake. If any one of you forgets a prayer or sleeps and misses it, let him pray it when he remembers it}}
\hadithdefcmd{nasai}{616}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - وَهُوَ ابْنُ الْمُبَارَكِ - عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِي النَّوْمِ تَفْرِيطٌ إِنَّمَا التَّفْرِيطُ فِيمَنْ لَمْ يُصَلِّ الصَّلاَةَ حَتَّى يَجِيءَ وَقْتُ الصَّلاَةِ الأُخْرَى حِينَ يَنْتَبِهُ لَهَا ‏"‏ ‏.‏\hadithno{616}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Qatadah said:"The Messenger of Allah (ﷺ) said: 'There is no negligence when one sleeps, rather negligence is when one does not offer one prayer until the time of the next prayer comes and he realizes that he has missed a prayer}}
\hadithdefcmd{nasai}{617}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا نَامُوا عَنِ الصَّلاَةِ حَتَّى طَلَعَتِ الشَّمْسُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَلْيُصَلِّهَا أَحَدُكُمْ مِنَ الْغَدِ لِوَقْتِهَا ‏"‏ ‏.‏\hadithno{617}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Qatadah that when they missed the prayer because they slept until the sun rose, the Messenger of Allah (ﷺ) said:"Let any one of you pray it during its time tomorrow}}
\hadithdefcmd{nasai}{618}{أَخْبَرَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا نَسِيتَ الصَّلاَةَ فَصَلِّ إِذَا ذَكَرْتَ فَإِنَّ اللَّهَ تَعَالَى يَقُولُ ‏\{‏ أَقِمِ الصَّلاَةَ لِذِكْرِي ‏\}‏ ‏"‏ ‏.‏ قَالَ عَبْدُ الأَعْلَى حَدَّثَنَا بِهِ يَعْلَى مُخْتَصَرًا ‏.‏\hadithno{618}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:The Messenger of Allah (ﷺ) said: If you forget a prayer, pray it when you remember it, for Allah says: "and perform the Salah for My remembrance." [1] [1] Ta-Ha 20:}}
\hadithdefcmd{nasai}{619}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّهَا إِذَا ذَكَرَهَا فَإِنَّ اللَّهَ تَعَالَى قَالَ ‏\{‏ أَقِمِ الصَّلاَةَ لِذِكْرِي ‏\}‏ ‏"‏ ‏.‏\hadithno{619}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Whoever forgets a prayer, let him pray it when he remembers it, for Allah says: and perform the Salah for My remembrance." [1] [1] Ta-Ha 20:}}
\hadithdefcmd{nasai}{620}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّهَا إِذَا ذَكَرَهَا فَإِنَّ اللَّهَ تَعَالَى يَقُولُ ‏\{‏ أَقِمِ الصَّلاَةِ لِلذِّكْرَى ‏\}‏ ‏"‏ ‏.‏ قُلْتُ لِلزُّهْرِيِّ هَكَذَا قَرَأَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏\hadithno{620}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ma'mar, from Az-Zuhri, from Sa'eed bin Al-Musayyab, that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'Whoever forgets a prayer, let him pray it when he remembers it, for Allah says: "and perform prayer when you remember (li dhikra).'" I said to Az-Zuhri: "Is that how the Messenger of Allah (ﷺ) recited it?" He said: "Yes}}
\hadithdefcmd{nasai}{621}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَأَسْرَيْنَا لَيْلَةً فَلَمَّا كَانَ فِي وَجْهِ الصُّبْحِ نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَامَ وَنَامَ النَّاسُ فَلَمْ نَسْتَيْقِظْ إِلاَّ بِالشَّمْسِ قَدْ طَلَعَتْ عَلَيْنَا فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُؤَذِّنَ فَأَذَّنَ ثُمَّ صَلَّى الرَّكْعَتَيْنِ قَبْلَ الْفَجْرِ ثُمَّ أَمَرَهُ فَأَقَامَ فَصَلَّى بِالنَّاسِ ثُمَّ حَدَّثَنَا بِمَا هُوَ كَائِنٌ حَتَّى تَقُومَ السَّاعَةُ ‏.‏\hadithno{621}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Buraid bin Abi Mariam that his father said:"We were with the Messenger of Allah (ﷺ) on a journey, and we kept going one night, then when it was nearly morning the Messenger of Allah (ﷺ) dismounted and slept, and the people slept too. We did not wake up until the sun had risen. The Messenger of Allah (ﷺ) asked the Mu'adhdhin to call the Adhan, then he prayed the two Rak'ahs before Fajr, then he asked him to say the Iqamah, then he led the people in prayer. Then he told us about everything that will happen until the Hour begins}}
\hadithdefcmd{nasai}{622}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِي عُبَيْدَةَ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَحُبِسْنَا عَنْ صَلاَةِ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ فَاشْتَدَّ ذَلِكَ عَلَىَّ فَقُلْتُ فِي نَفْسِي نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَفِي سَبِيلِ اللَّهِ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلاَلاً فَأَقَامَ فَصَلَّى بِنَا الظُّهْرَ ثُمَّ أَقَامَ فَصَلَّى بِنَا الْعَصْرَ ثُمَّ أَقَامَ فَصَلَّى بِنَا الْمَغْرِبَ ثُمَّ أَقَامَ فَصَلَّى بِنَا الْعِشَاءَ ثُمَّ طَافَ عَلَيْنَا فَقَالَ ‏ "‏ مَا عَلَى الأَرْضِ عِصَابَةٌ يَذْكُرُونَ اللَّهَ عَزَّ وَجَلَّ غَيْرُكُمْ ‏"‏ ‏.‏\hadithno{622}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"We were with the Messenger of Allah (ﷺ) and we were prevented from praying Zuhr, 'Asr, Maghrib and 'Isha'. I felt very upset about that and I said to myself: 'We are with the Messenger of Allah (ﷺ) and (fighting) for the sake of Allah.' Then the Messenger of Allah (ﷺ) commanded Bilal to say the Iqamah and he led us in praying Zuhr. Then he said the Iqamah and he led us in praying 'Asr. Then he said the Iqamah and he led us in praying Maghrib. Then he said the Iqamah and he led us in praying 'Isha'. Then he went around among us and told us: 'There is no group on Earth who is remembering Allah, the Mighty and Sublime, except you}}
\hadithdefcmd{nasai}{623}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ يَزِيدَ بْنِ كَيْسَانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ عَرَّسْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ نَسْتَيْقِظْ حَتَّى طَلَعَتِ الشَّمْسُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِيَأْخُذْ كُلُّ رَجُلٍ بِرَأْسِ رَاحِلَتِهِ فَإِنَّ هَذَا مَنْزِلٌ حَضَرَنَا فِيهِ الشَّيْطَانُ ‏"‏ ‏.‏ قَالَ فَفَعَلْنَا فَدَعَا بِالْمَاءِ فَتَوَضَّأَ ثُمَّ صَلَّى سَجْدَتَيْنِ ثُمَّ أُقِيمَتِ الصَّلاَةُ فَصَلَّى الْغَدَاةَ ‏.‏\hadithno{623}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"We stopped to camp at the end of the night with the Messenger of Allah (ﷺ), and we did not wake up until the sun had risen. The Messenger of Allah (ﷺ) said: 'Let each man take hold of his camel's head (and leave), for the Shaitan was here in this place with us.' We did that, then he called for water and performed Wudu', then he prayed two Rak'ahs, then the Iqamah was said and he prayed Al-Ghadah (Fajr)}}
\hadithdefcmd{nasai}{624}{أَخْبَرَنَا أَبُو عَاصِمٍ، خُشَيْشُ بْنُ أَصْرَمَ قَالَ حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي سَفَرٍ لَهُ ‏"‏ مَنْ يَكْلَؤُنَا اللَّيْلَةَ لاَ نَرْقُدَ عَنْ صَلاَةِ الصُّبْحِ ‏"‏ ‏.‏ قَالَ بِلاَلٌ أَنَا ‏.‏ فَاسْتَقْبَلَ مَطْلَعَ الشَّمْسِ فَضُرِبَ عَلَى آذَانِهِمْ حَتَّى أَيْقَظَهُمْ حَرُّ الشَّمْسِ فَقَامُوا فَقَالَ ‏"‏ تَوَضَّئُوا ‏"‏ ‏.‏ ثُمَّ أَذَّنَ بِلاَلٌ فَصَلَّى رَكْعَتَيْنِ وَصَلَّوْا رَكْعَتَىِ الْفَجْرِ ثُمَّ صَلَّوُا الْفَجْرَ ‏.‏\hadithno{624}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Nafi' bin Jubair, from his father, that the Messenger of Allah (ﷺ) said during a journey:"Who will watch out for dawn for us, so that we do not sleep and miss the dawn prayer?" Bilal said: 'I will.' He turned to face the direction where the sun woke them up, then they got up. He said: 'Perform Wudu'.' Then Bilal called the Adhan and he prayed two Rak'ahs, and they prayed the two (Sunnah) Rak'ahs of Fajr, then they prayed Fajr}}
\hadithdefcmd{nasai}{625}{أَخْبَرَنَا أَبُو عَاصِمٍ، قَالَ حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا حَبِيبٌ، عَنْ عَمْرِو بْنِ هَرِمٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَدْلَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ عَرَّسَ فَلَمْ يَسْتَيْقِظْ حَتَّى طَلَعَتِ الشَّمْسُ أَوْ بَعْضُهَا فَلَمْ يُصَلِّ حَتَّى ارْتَفَعَتِ الشَّمْسُ فَصَلَّى وَهِيَ صَلاَةُ الْوُسْطَى ‏.‏\hadithno{625}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah (ﷺ) set out at nightfall, then stopped to camp at the end of the night, and he did not wake up until the sun had risen or had partly risen. He did not pray until the sun had risen (fully), then he prayed, and that was the 'middle prayer' (Salat Al-Wusta)}}
